# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import messaging_pb2 as messaging__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class MessagingStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.DoInteractiveMediaAction = channel.unary_unary(
        '/dialog.Messaging/DoInteractiveMediaAction',
        request_serializer=messaging__pb2.RequestDoInteractiveMediaAction.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SendMessage = channel.unary_unary(
        '/dialog.Messaging/SendMessage',
        request_serializer=messaging__pb2.RequestSendMessage.SerializeToString,
        response_deserializer=messaging__pb2.ResponseSendMessage.FromString,
        )
    self.UpdateMessage = channel.unary_unary(
        '/dialog.Messaging/UpdateMessage',
        request_serializer=messaging__pb2.RequestUpdateMessage.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.MessageReceived = channel.unary_unary(
        '/dialog.Messaging/MessageReceived',
        request_serializer=messaging__pb2.RequestMessageReceived.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.MessageRead = channel.unary_unary(
        '/dialog.Messaging/MessageRead',
        request_serializer=messaging__pb2.RequestMessageRead.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.DeleteMessageObsolete = channel.unary_unary(
        '/dialog.Messaging/DeleteMessageObsolete',
        request_serializer=messaging__pb2.RequestDeleteMessageObsolete.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.ClearChat = channel.unary_unary(
        '/dialog.Messaging/ClearChat',
        request_serializer=messaging__pb2.RequestClearChat.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.DeleteChat = channel.unary_unary(
        '/dialog.Messaging/DeleteChat',
        request_serializer=messaging__pb2.RequestDeleteChat.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.ArchiveChat = channel.unary_unary(
        '/dialog.Messaging/ArchiveChat',
        request_serializer=messaging__pb2.RequestArchiveChat.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.MessageSetReaction = channel.unary_unary(
        '/dialog.Messaging/MessageSetReaction',
        request_serializer=messaging__pb2.RequestMessageSetReaction.SerializeToString,
        response_deserializer=messaging__pb2.ResponseReactionsResponse.FromString,
        )
    self.MessageRemoveReaction = channel.unary_unary(
        '/dialog.Messaging/MessageRemoveReaction',
        request_serializer=messaging__pb2.RequestMessageRemoveReaction.SerializeToString,
        response_deserializer=messaging__pb2.ResponseReactionsResponse.FromString,
        )
    self.LoadHistory = channel.unary_unary(
        '/dialog.Messaging/LoadHistory',
        request_serializer=messaging__pb2.RequestLoadHistory.SerializeToString,
        response_deserializer=messaging__pb2.ResponseLoadHistory.FromString,
        )
    self.LoadDialogs = channel.unary_unary(
        '/dialog.Messaging/LoadDialogs',
        request_serializer=messaging__pb2.RequestLoadDialogs.SerializeToString,
        response_deserializer=messaging__pb2.ResponseLoadDialogs.FromString,
        )
    self.FetchDialogIndex = channel.unary_unary(
        '/dialog.Messaging/FetchDialogIndex',
        request_serializer=messaging__pb2.RequestFetchDialogIndex.SerializeToString,
        response_deserializer=messaging__pb2.ResponseFetchDialogIndex.FromString,
        )
    self.LoadArchived = channel.unary_unary(
        '/dialog.Messaging/LoadArchived',
        request_serializer=messaging__pb2.RequestLoadArchived.SerializeToString,
        response_deserializer=messaging__pb2.ResponseLoadArchived.FromString,
        )
    self.LoadGroupedDialogs = channel.unary_unary(
        '/dialog.Messaging/LoadGroupedDialogs',
        request_serializer=messaging__pb2.RequestLoadGroupedDialogs.SerializeToString,
        response_deserializer=messaging__pb2.ResponseLoadGroupedDialogs.FromString,
        )
    self.HideDialog = channel.unary_unary(
        '/dialog.Messaging/HideDialog',
        request_serializer=messaging__pb2.RequestHideDialog.SerializeToString,
        response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
        )
    self.ShowDialog = channel.unary_unary(
        '/dialog.Messaging/ShowDialog',
        request_serializer=messaging__pb2.RequestShowDialog.SerializeToString,
        response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
        )
    self.FavouriteDialog = channel.unary_unary(
        '/dialog.Messaging/FavouriteDialog',
        request_serializer=messaging__pb2.RequestFavouriteDialog.SerializeToString,
        response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
        )
    self.UnfavouriteDialog = channel.unary_unary(
        '/dialog.Messaging/UnfavouriteDialog',
        request_serializer=messaging__pb2.RequestUnfavouriteDialog.SerializeToString,
        response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
        )
    self.NotifyDialogOpened = channel.unary_unary(
        '/dialog.Messaging/NotifyDialogOpened',
        request_serializer=messaging__pb2.RequestNotifyDialogOpened.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.PinMessage = channel.unary_unary(
        '/dialog.Messaging/PinMessage',
        request_serializer=messaging__pb2.RequestPinMessage.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.UnpinMessage = channel.unary_unary(
        '/dialog.Messaging/UnpinMessage',
        request_serializer=messaging__pb2.RequestUnpinMessage.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )


class MessagingServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def DoInteractiveMediaAction(self, request, context):
    """/ Interact with a message media (click on button for example)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageReceived(self, request, context):
    """/ Mark message as received by self
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageRead(self, request, context):
    """/ Mark message as read by self
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMessageObsolete(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearChat(self, request, context):
    """/ Clear chat history
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteChat(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ArchiveChat(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageSetReaction(self, request, context):
    """/ Add reaction on message (emoji)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageRemoveReaction(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadHistory(self, request, context):
    """/ Load conversation history
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadDialogs(self, request, context):
    """/ Load user's dialogs
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FetchDialogIndex(self, request, context):
    """/ Load short info about all user's dialogs
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadArchived(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadGroupedDialogs(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HideDialog(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ShowDialog(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FavouriteDialog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnfavouriteDialog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def NotifyDialogOpened(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PinMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnpinMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MessagingServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'DoInteractiveMediaAction': grpc.unary_unary_rpc_method_handler(
          servicer.DoInteractiveMediaAction,
          request_deserializer=messaging__pb2.RequestDoInteractiveMediaAction.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SendMessage': grpc.unary_unary_rpc_method_handler(
          servicer.SendMessage,
          request_deserializer=messaging__pb2.RequestSendMessage.FromString,
          response_serializer=messaging__pb2.ResponseSendMessage.SerializeToString,
      ),
      'UpdateMessage': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateMessage,
          request_deserializer=messaging__pb2.RequestUpdateMessage.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'MessageReceived': grpc.unary_unary_rpc_method_handler(
          servicer.MessageReceived,
          request_deserializer=messaging__pb2.RequestMessageReceived.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'MessageRead': grpc.unary_unary_rpc_method_handler(
          servicer.MessageRead,
          request_deserializer=messaging__pb2.RequestMessageRead.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'DeleteMessageObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMessageObsolete,
          request_deserializer=messaging__pb2.RequestDeleteMessageObsolete.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'ClearChat': grpc.unary_unary_rpc_method_handler(
          servicer.ClearChat,
          request_deserializer=messaging__pb2.RequestClearChat.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'DeleteChat': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteChat,
          request_deserializer=messaging__pb2.RequestDeleteChat.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'ArchiveChat': grpc.unary_unary_rpc_method_handler(
          servicer.ArchiveChat,
          request_deserializer=messaging__pb2.RequestArchiveChat.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'MessageSetReaction': grpc.unary_unary_rpc_method_handler(
          servicer.MessageSetReaction,
          request_deserializer=messaging__pb2.RequestMessageSetReaction.FromString,
          response_serializer=messaging__pb2.ResponseReactionsResponse.SerializeToString,
      ),
      'MessageRemoveReaction': grpc.unary_unary_rpc_method_handler(
          servicer.MessageRemoveReaction,
          request_deserializer=messaging__pb2.RequestMessageRemoveReaction.FromString,
          response_serializer=messaging__pb2.ResponseReactionsResponse.SerializeToString,
      ),
      'LoadHistory': grpc.unary_unary_rpc_method_handler(
          servicer.LoadHistory,
          request_deserializer=messaging__pb2.RequestLoadHistory.FromString,
          response_serializer=messaging__pb2.ResponseLoadHistory.SerializeToString,
      ),
      'LoadDialogs': grpc.unary_unary_rpc_method_handler(
          servicer.LoadDialogs,
          request_deserializer=messaging__pb2.RequestLoadDialogs.FromString,
          response_serializer=messaging__pb2.ResponseLoadDialogs.SerializeToString,
      ),
      'FetchDialogIndex': grpc.unary_unary_rpc_method_handler(
          servicer.FetchDialogIndex,
          request_deserializer=messaging__pb2.RequestFetchDialogIndex.FromString,
          response_serializer=messaging__pb2.ResponseFetchDialogIndex.SerializeToString,
      ),
      'LoadArchived': grpc.unary_unary_rpc_method_handler(
          servicer.LoadArchived,
          request_deserializer=messaging__pb2.RequestLoadArchived.FromString,
          response_serializer=messaging__pb2.ResponseLoadArchived.SerializeToString,
      ),
      'LoadGroupedDialogs': grpc.unary_unary_rpc_method_handler(
          servicer.LoadGroupedDialogs,
          request_deserializer=messaging__pb2.RequestLoadGroupedDialogs.FromString,
          response_serializer=messaging__pb2.ResponseLoadGroupedDialogs.SerializeToString,
      ),
      'HideDialog': grpc.unary_unary_rpc_method_handler(
          servicer.HideDialog,
          request_deserializer=messaging__pb2.RequestHideDialog.FromString,
          response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
      ),
      'ShowDialog': grpc.unary_unary_rpc_method_handler(
          servicer.ShowDialog,
          request_deserializer=messaging__pb2.RequestShowDialog.FromString,
          response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
      ),
      'FavouriteDialog': grpc.unary_unary_rpc_method_handler(
          servicer.FavouriteDialog,
          request_deserializer=messaging__pb2.RequestFavouriteDialog.FromString,
          response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
      ),
      'UnfavouriteDialog': grpc.unary_unary_rpc_method_handler(
          servicer.UnfavouriteDialog,
          request_deserializer=messaging__pb2.RequestUnfavouriteDialog.FromString,
          response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
      ),
      'NotifyDialogOpened': grpc.unary_unary_rpc_method_handler(
          servicer.NotifyDialogOpened,
          request_deserializer=messaging__pb2.RequestNotifyDialogOpened.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'PinMessage': grpc.unary_unary_rpc_method_handler(
          servicer.PinMessage,
          request_deserializer=messaging__pb2.RequestPinMessage.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'UnpinMessage': grpc.unary_unary_rpc_method_handler(
          servicer.UnpinMessage,
          request_deserializer=messaging__pb2.RequestUnpinMessage.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Messaging', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
