# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_sync.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config_sync.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x11\x63onfig_sync.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"D\n\tParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05value\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"4\n\x14RequestGetParameters:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n\x15ResponseGetParameters\x12%\n\nparameters\x18\x01 \x03(\x0b\x32\x11.dialog.Parameter:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x8b\x01\n\x14RequestEditParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"o\n\x16UpdateParameterChanged\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden2\xfa\x01\n\nConfigSync\x12z\n\rGetParameters\x12\x1c.dialog.RequestGetParameters\x1a\x1d.dialog.ResponseGetParameters\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/GetParameters:\x01*\x12p\n\rEditParameter\x12\x1c.dialog.RequestEditParameter\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/EditParameter:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='dialog.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.Parameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.Parameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=222,
)


_REQUESTGETPARAMETERS = _descriptor.Descriptor(
  name='RequestGetParameters',
  full_name='dialog.RequestGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=276,
)


_RESPONSEGETPARAMETERS = _descriptor.Descriptor(
  name='ResponseGetParameters',
  full_name='dialog.ResponseGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='dialog.ResponseGetParameters.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=371,
)


_REQUESTEDITPARAMETER = _descriptor.Descriptor(
  name='RequestEditParameter',
  full_name='dialog.RequestEditParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.RequestEditParameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.RequestEditParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=513,
)


_UPDATEPARAMETERCHANGED = _descriptor.Descriptor(
  name='UpdateParameterChanged',
  full_name='dialog.UpdateParameterChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.UpdateParameterChanged.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.UpdateParameterChanged.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=626,
)

_RESPONSEGETPARAMETERS.fields_by_name['parameters'].message_type = _PARAMETER
_REQUESTEDITPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPARAMETERCHANGED.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['RequestGetParameters'] = _REQUESTGETPARAMETERS
DESCRIPTOR.message_types_by_name['ResponseGetParameters'] = _RESPONSEGETPARAMETERS
DESCRIPTOR.message_types_by_name['RequestEditParameter'] = _REQUESTEDITPARAMETER
DESCRIPTOR.message_types_by_name['UpdateParameterChanged'] = _UPDATEPARAMETERCHANGED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

RequestGetParameters = _reflection.GeneratedProtocolMessageType('RequestGetParameters', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETPARAMETERS,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetParameters)
  ))
_sym_db.RegisterMessage(RequestGetParameters)

ResponseGetParameters = _reflection.GeneratedProtocolMessageType('ResponseGetParameters', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETPARAMETERS,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetParameters)
  ))
_sym_db.RegisterMessage(ResponseGetParameters)

RequestEditParameter = _reflection.GeneratedProtocolMessageType('RequestEditParameter', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITPARAMETER,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditParameter)
  ))
_sym_db.RegisterMessage(RequestEditParameter)

UpdateParameterChanged = _reflection.GeneratedProtocolMessageType('UpdateParameterChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPARAMETERCHANGED,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateParameterChanged)
  ))
_sym_db.RegisterMessage(UpdateParameterChanged)


DESCRIPTOR._options = None
_PARAMETER.fields_by_name['key']._options = None
_PARAMETER.fields_by_name['value']._options = None
_REQUESTGETPARAMETERS._options = None
_RESPONSEGETPARAMETERS._options = None
_REQUESTEDITPARAMETER.fields_by_name['key']._options = None
_REQUESTEDITPARAMETER.fields_by_name['value']._options = None
_REQUESTEDITPARAMETER._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['key']._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['value']._options = None

_CONFIGSYNC = _descriptor.ServiceDescriptor(
  name='ConfigSync',
  full_name='dialog.ConfigSync',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=629,
  serialized_end=879,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetParameters',
    full_name='dialog.ConfigSync.GetParameters',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETPARAMETERS,
    output_type=_RESPONSEGETPARAMETERS,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/ConfigSync/GetParameters:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditParameter',
    full_name='dialog.ConfigSync.EditParameter',
    index=1,
    containing_service=None,
    input_type=_REQUESTEDITPARAMETER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/ConfigSync/EditParameter:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGSYNC)

DESCRIPTOR.services_by_name['ConfigSync'] = _CONFIGSYNC

# @@protoc_insertion_point(module_scope)
