# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import push_pb2 as push__pb2


class PushStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RegisterGooglePush = channel.unary_unary(
        '/dialog.Push/RegisterGooglePush',
        request_serializer=push__pb2.RequestRegisterGooglePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterGooglePush = channel.unary_unary(
        '/dialog.Push/UnregisterGooglePush',
        request_serializer=push__pb2.RequestUnregisterGooglePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePush = channel.unary_unary(
        '/dialog.Push/RegisterApplePush',
        request_serializer=push__pb2.RequestRegisterApplePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePush = channel.unary_unary(
        '/dialog.Push/UnregisterApplePush',
        request_serializer=push__pb2.RequestUnregisterApplePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePushKit = channel.unary_unary(
        '/dialog.Push/RegisterApplePushKit',
        request_serializer=push__pb2.RequestRegisterApplePushKit.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePushKit = channel.unary_unary(
        '/dialog.Push/UnregisterApplePushKit',
        request_serializer=push__pb2.RequestUnregisterApplePushKit.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePushToken = channel.unary_unary(
        '/dialog.Push/RegisterApplePushToken',
        request_serializer=push__pb2.RequestRegisterApplePushToken.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePushToken = channel.unary_unary(
        '/dialog.Push/UnregisterApplePushToken',
        request_serializer=push__pb2.RequestUnregisterApplePushToken.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class PushServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RegisterGooglePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterGooglePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePushKit(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePushKit(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePushToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePushToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RegisterGooglePush': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterGooglePush,
          request_deserializer=push__pb2.RequestRegisterGooglePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterGooglePush': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterGooglePush,
          request_deserializer=push__pb2.RequestUnregisterGooglePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePush': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePush,
          request_deserializer=push__pb2.RequestRegisterApplePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePush': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePush,
          request_deserializer=push__pb2.RequestUnregisterApplePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePushKit': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePushKit,
          request_deserializer=push__pb2.RequestRegisterApplePushKit.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePushKit': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePushKit,
          request_deserializer=push__pb2.RequestUnregisterApplePushKit.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePushToken': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePushToken,
          request_deserializer=push__pb2.RequestRegisterApplePushToken.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePushToken': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePushToken,
          request_deserializer=push__pb2.RequestUnregisterApplePushToken.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Push', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
