# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import config_sync_pb2 as config__sync__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class ConfigSyncStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetParameters = channel.unary_unary(
        '/dialog.ConfigSync/GetParameters',
        request_serializer=config__sync__pb2.RequestGetParameters.SerializeToString,
        response_deserializer=config__sync__pb2.ResponseGetParameters.FromString,
        )
    self.EditParameter = channel.unary_unary(
        '/dialog.ConfigSync/EditParameter',
        request_serializer=config__sync__pb2.RequestEditParameter.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )


class ConfigSyncServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetParameters(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditParameter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConfigSyncServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetParameters': grpc.unary_unary_rpc_method_handler(
          servicer.GetParameters,
          request_deserializer=config__sync__pb2.RequestGetParameters.FromString,
          response_serializer=config__sync__pb2.ResponseGetParameters.SerializeToString,
      ),
      'EditParameter': grpc.unary_unary_rpc_method_handler(
          servicer.EditParameter,
          request_deserializer=config__sync__pb2.RequestEditParameter.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.ConfigSync', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
