# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messaging.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import groups_pb2 as groups__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from . import users_pb2 as users__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messaging.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x0fmessaging.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0cgroups.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x0busers.proto\x1a\x15scalapb/scalapb.proto\"\x9b\x02\n\x11MessageAttributes\x12?\n\x0cis_mentioned\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x41\n\x0eis_highlighted\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0bis_notified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x42\n\x0fis_only_for_you\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"\xed\x01\n\rQuotedMessage\x12!\n\nmessage_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12&\n\x0fpublic_group_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12%\n\x0esender_user_id\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0cmessage_date\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x45\n\x16quoted_message_content\x18\x05 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\"\xe7\x01\n\x0cMessageMedia\x12\x34\n\x07webpage\x18\x01 \x01(\x0b\x32\x14.dialog.WebpageMediaB\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x05image\x18\x02 \x01(\x0b\x32\x12.dialog.ImageMediaB\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x05\x61udio\x18\x03 \x01(\x0b\x32\x12.dialog.AudioMediaB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x07\x61\x63tions\x18\x06 \x03(\x0b\x32\x1d.dialog.InteractiveMediaGroupB\r\x8a\xea\x30\t\n\x07visible\"\xf8\x01\n\x0cWebpageMedia\x12\x37\n\x03url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x39\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12?\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x33\n\x05image\x18\x04 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\"A\n\nImageMedia\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\"A\n\nAudioMedia\x12\x33\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x15.dialog.AudioLocationB\r\x8a\xea\x30\t\n\x07visible\"\xa4\x01\n\x16InteractiveMediaWidget\x12@\n\x16interactiveMediaButton\x18\x01 \x01(\x0b\x32\x1e.dialog.InteractiveMediaButtonH\x00\x12@\n\x16interactiveMediaSelect\x18\x02 \x01(\x0b\x32\x1e.dialog.InteractiveMediaSelectH\x00\x42\x06\n\x04\x62ody\"r\n\x16InteractiveMediaButton\x12\x1c\n\x05value\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05label\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xde\x01\n\x16InteractiveMediaSelect\x12\x44\n\x07options\x18\x01 \x03(\x0b\x32$.dialog.InteractiveMediaSelectOptionB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05label\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x42\n\rdefault_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"Z\n\x1cInteractiveMediaSelectOption\x12\x1c\n\x05value\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05label\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"\xea\x01\n\x10InteractiveMedia\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x06widget\x18\x02 \x01(\x0b\x32\x1e.dialog.InteractiveMediaWidgetB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x05style\x18\x03 \x01(\x0e\x32\x1d.dialog.InteractiveMediaStyleB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x07\x63onfirm\x18\x04 \x01(\x0b\x32\x1f.dialog.InteractiveMediaConfirmB\r\x8a\xea\x30\t\n\x07visible\"V\n\x1bInteractiveMediaTranslation\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"\x89\x01\n InteractiveMediaTranslationGroup\x12\x1f\n\x08language\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x08messages\x18\x02 \x03(\x0b\x32#.dialog.InteractiveMediaTranslationB\r\x8a\xea\x30\t\n\x07visible\"\x9c\x02\n\x15InteractiveMediaGroup\x12\x38\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x18.dialog.InteractiveMediaB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12?\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12M\n\x0ctranslations\x18\x04 \x03(\x0b\x32(.dialog.InteractiveMediaTranslationGroupB\r\x8a\xea\x30\t\n\x07visible\"\x87\x02\n\x17InteractiveMediaConfirm\x12\x39\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x02ok\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x07\x64ismiss\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xa1\x01\n\x1bUpdateInteractiveMediaEvent\x12-\n\x03mid\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x19\n\x02id\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xa7\x01\n\x1fRequestDoInteractiveMediaAction\x12-\n\x03mid\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x19\n\x02id\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xd2\x03\n\x0eMessageContent\x12*\n\x0btextMessage\x18\x01 \x01(\x0b\x32\x13.dialog.TextMessageH\x00\x12\x30\n\x0eserviceMessage\x18\x02 \x01(\x0b\x32\x16.dialog.ServiceMessageH\x00\x12\x32\n\x0f\x64ocumentMessage\x18\x03 \x01(\x0b\x32\x17.dialog.DocumentMessageH\x00\x12*\n\x0bjsonMessage\x18\x04 \x01(\x0b\x32\x13.dialog.JsonMessageH\x00\x12\x38\n\x12unsupportedMessage\x18\x05 \x01(\x0b\x32\x1a.dialog.UnsupportedMessageH\x00\x12\x30\n\x0estickerMessage\x18\x06 \x01(\x0b\x32\x16.dialog.StickerMessageH\x00\x12.\n\rbinaryMessage\x18\x07 \x01(\x0b\x32\x15.dialog.BinaryMessageH\x00\x12,\n\x0c\x65mptyMessage\x18\x08 \x01(\x0b\x32\x14.dialog.EmptyMessageH\x00\x12\x30\n\x0e\x64\x65letedMessage\x18\t \x01(\x0b\x32\x16.dialog.DeletedMessageH\x00\x42\x06\n\x04\x62ody\"\xe1\x01\n\x0bTextMessage\x12\x1a\n\x04text\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1f\n\x08mentions\x18\x02 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\x03\x65xt\x18\x03 \x01(\x0b\x32\x15.dialog.TextMessageExB\r\x8a\xea\x30\t\n\x07visible\x12\x32\n\x05media\x18\x04 \x03(\x0b\x32\x14.dialog.MessageMediaB\r\x8a\xea\x30\t\n\x07visible\x12.\n\nextensions\x18\x05 \x03(\x0b\x32\x0b.dialog.AnyB\r\x8a\xea\x30\t\n\x07visible\"\xad\x01\n\rTextMessageEx\x12\x30\n\x0etextExMarkdown\x18\x01 \x01(\x0b\x32\x16.dialog.TextExMarkdownH\x00\x12\x36\n\x11textModernMessage\x18\x02 \x01(\x0b\x32\x19.dialog.TextModernMessageH\x00\x12*\n\x0btextCommand\x18\x03 \x01(\x0b\x32\x13.dialog.TextCommandH\x00\x42\x06\n\x04\x62ody\"0\n\x0eTextExMarkdown\x12\x1e\n\x08markdown\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"\xc7\x02\n\x11TextModernMessage\x12\x38\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12I\n\x14sender_name_override\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x15sender_photo_override\x18\x03 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\x05style\x18\x04 \x01(\x0b\x32\x16.dialog.ParagraphStyleB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x08\x61ttaches\x18\x05 \x03(\x0b\x32\x18.dialog.TextModernAttachB\r\x8a\xea\x30\t\n\x07visible\"\xba\x01\n\x0eParagraphStyle\x12\x41\n\x0eshow_paragraph\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x0fparagraph_color\x18\x02 \x01(\x0b\x32\r.dialog.ColorB\r\x8a\xea\x30\t\n\x07visible\x12.\n\x08\x62g_color\x18\x03 \x01(\x0b\x32\r.dialog.ColorB\r\x8a\xea\x30\t\n\x07visible\"\xe0\x02\n\x10TextModernAttach\x12\x39\n\x05title\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12>\n\ttitle_url\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\ntitle_icon\x18\x03 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x34\n\x05style\x18\x05 \x01(\x0b\x32\x16.dialog.ParagraphStyleB\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x06\x66ields\x18\x06 \x03(\x0b\x32\x17.dialog.TextModernField\"\x8a\x01\n\x0fTextModernField\x12\x1c\n\x05title\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x08is_short\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"J\n\x0bTextCommand\x12\x1e\n\x07\x63ommand\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x61rgs\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"[\n\x0eServiceMessage\x12\x1a\n\x04text\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12-\n\x03\x65xt\x18\x03 \x01(\x0b\x32\x11.dialog.ServiceExB\r\x8a\xea\x30\t\n\x07\x63ompact\"\xc0\x06\n\tServiceEx\x12\x33\n\x0buserInvited\x18\x01 \x01(\x0b\x32\x1c.dialog.ServiceExUserInvitedH\x00\x12\x31\n\nuserJoined\x18\x02 \x01(\x0b\x32\x1b.dialog.ServiceExUserJoinedH\x00\x12\x31\n\nuserKicked\x18\x03 \x01(\x0b\x32\x1b.dialog.ServiceExUserKickedH\x00\x12-\n\x08userLeft\x18\x04 \x01(\x0b\x32\x19.dialog.ServiceExUserLeftH\x00\x12\x35\n\x0cgroupCreated\x18\x05 \x01(\x0b\x32\x1d.dialog.ServiceExGroupCreatedH\x00\x12\x35\n\x0c\x63hangedTitle\x18\x06 \x01(\x0b\x32\x1d.dialog.ServiceExChangedTitleH\x00\x12\x35\n\x0c\x63hangedTopic\x18\x07 \x01(\x0b\x32\x1d.dialog.ServiceExChangedTopicH\x00\x12\x35\n\x0c\x63hangedAbout\x18\x08 \x01(\x0b\x32\x1d.dialog.ServiceExChangedAboutH\x00\x12\x37\n\rchangedAvatar\x18\t \x01(\x0b\x32\x1e.dialog.ServiceExChangedAvatarH\x00\x12?\n\x11\x63ontactRegistered\x18\n \x01(\x0b\x32\".dialog.ServiceExContactRegisteredH\x00\x12\x33\n\x0bphoneMissed\x18\x0b \x01(\x0b\x32\x1c.dialog.ServiceExPhoneMissedH\x00\x12/\n\tphoneCall\x18\x0c \x01(\x0b\x32\x1a.dialog.ServiceExPhoneCallH\x00\x12\x37\n\rphoneRejected\x18\r \x01(\x0b\x32\x1e.dialog.ServiceExPhoneRejectedH\x00\x12\x35\n\x0c\x63hatArchived\x18\x0e \x01(\x0b\x32\x1d.dialog.ServiceExChatArchivedH\x00\x12\x35\n\x0c\x63hatRestored\x18\x0f \x01(\x0b\x32\x1d.dialog.ServiceExChatRestoredH\x00\x42\x06\n\x04\x62ody\":\n\x14ServiceExUserInvited\x12\"\n\x0binvited_uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x15\n\x13ServiceExUserJoined\"8\n\x13ServiceExUserKicked\x12!\n\nkicked_uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x13\n\x11ServiceExUserLeft\"\x17\n\x15ServiceExGroupCreated\"4\n\x15ServiceExChangedTitle\x12\x1b\n\x05title\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"R\n\x15ServiceExChangedTopic\x12\x39\n\x05topic\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"R\n\x15ServiceExChangedAbout\x12\x39\n\x05\x61\x62out\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"G\n\x16ServiceExChangedAvatar\x12-\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\"8\n\x1aServiceExContactRegistered\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x16\n\x14ServiceExPhoneMissed\"5\n\x12ServiceExPhoneCall\x12\x1f\n\x08\x64uration\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x18\n\x16ServiceExPhoneRejected\"\x17\n\x15ServiceExChatArchived\"\x17\n\x15ServiceExChatRestored\"\x95\x02\n\x0f\x44ocumentMessage\x12\x1e\n\x07\x66ile_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12 \n\tfile_size\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x04name\x18\x04 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12 \n\tmime_type\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12/\n\x05thumb\x18\x06 \x01(\x0b\x32\x11.dialog.FastThumbB\r\x8a\xea\x30\t\n\x07\x63ompact\x12.\n\x03\x65xt\x18\x08 \x01(\x0b\x32\x12.dialog.DocumentExB\r\x8a\xea\x30\t\n\x07\x63ompact\"\x92\x01\n\nDocumentEx\x12(\n\x05photo\x18\x01 \x01(\x0b\x32\x17.dialog.DocumentExPhotoH\x00\x12(\n\x05video\x18\x02 \x01(\x0b\x32\x17.dialog.DocumentExVideoH\x00\x12(\n\x05voice\x18\x03 \x01(\x0b\x32\x17.dialog.DocumentExVoiceH\x00\x42\x06\n\x04\x62ody\"E\n\x0f\x44ocumentExPhoto\x12\x18\n\x01w\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x18\n\x01h\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"f\n\x0f\x44ocumentExVideo\x12\x18\n\x01w\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x18\n\x01h\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08\x64uration\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"2\n\x0f\x44ocumentExVoice\x12\x1f\n\x08\x64uration\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"-\n\x0bJsonMessage\x12\x1e\n\x08raw_json\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"\x14\n\x12UnsupportedMessage\"\xde\x03\n\x0eStickerMessage\x12>\n\nsticker_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0c\x66\x61st_preview\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\timage_512\x18\x03 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\timage_256\x18\x04 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\x12I\n\x15sticker_collection_id\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12R\n\x1esticker_collection_access_hash\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x65moji\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"O\n\rBinaryMessage\x12\"\n\x0b\x63ontent_tag\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03msg\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\"\x0e\n\x0c\x45mptyMessage\"M\n\x0e\x44\x65letedMessage\x12;\n\x08is_local\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07\x63ompact\"u\n\x0b\x44ialogShort\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07\x63ounter\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"{\n\x0b\x44ialogGroup\x12\x1b\n\x05title\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1a\n\x03key\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x33\n\x07\x64ialogs\x18\x03 \x03(\x0b\x32\x13.dialog.DialogShortB\r\x8a\xea\x30\t\n\x07visible\"L\n\x0fMessageReaction\x12\x1c\n\x05users\x18\x01 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x63ode\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"L\n\x0fSearchPredicate\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06values\x18\x02 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\"\xe2\x03\n\x12RequestSendMessage\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10\x64\x65\x64uplication_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07message\x18\x04 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10is_only_for_user\x18\x05 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\x07\x66orward\x18\x08 \x01(\x0b\x32\x1a.dialog.ReferencedMessagesB\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\x05reply\x18\t \x01(\x0b\x32\x1a.dialog.ReferencedMessagesB\r\x8a\xea\x30\t\n\x07visible\x12:\n\npredicates\x18\n \x03(\x0b\x32\x17.dialog.SearchPredicateB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nwhite_list\x18\x0b \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nblack_list\x18\x0c \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xca\x01\n\x14RequestUpdateMessage\x12-\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0fupdated_message\x18\x03 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12%\n\x0elast_edited_at\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x81\x01\n\x16RequestMessageReceived\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"}\n\x12RequestMessageRead\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"l\n\x1cRequestDeleteMessageObsolete\x12.\n\x04mids\x18\x03 \x03(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x88\x01\n\x10RequestClearChat\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12(\n\x11last_message_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x89\x01\n\x11RequestDeleteChat\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12(\n\x11last_message_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"`\n\x12RequestArchiveChat\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb3\x01\n\x19RequestMessageSetReaction\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb6\x01\n\x1cRequestMessageRemoveReaction\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x82\x01\n\x19ResponseReactionsResponse\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12*\n\treactions\x18\x03 \x03(\x0b\x32\x17.dialog.MessageReaction:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"c\n\x13ResponseSendMessage\x12-\n\x03mid\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x98\x04\n\rUpdateMessage\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsender_uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x08 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07message\x18\x05 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12<\n\nattributes\x18\x06 \x01(\x0b\x32\x19.dialog.MessageAttributesB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x07\x66orward\x18\t \x01(\x0b\x32\x1a.dialog.ReferencedMessagesB\r\x8a\xea\x30\t\n\x07visibleH\x00\x12:\n\x05reply\x18\n \x01(\x0b\x32\x1a.dialog.ReferencedMessagesB\r\x8a\xea\x30\t\n\x07visibleH\x00\x12\x36\n\x0cprevious_mid\x18\x0b \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x07\x63ounter\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visibleB\x08\n\x06\x61ttach\"\xd1\x01\n\x1bUpdateMessageContentChanged\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07message\x18\x03 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tedited_at\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\x9e\x02\n\x11UpdateMessageSent\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x32\n\x08prev_mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x42\n\x0eunread_counter\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\"\x8b\x01\n\x15UpdateMessageReceived\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nstart_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\rreceived_date\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\x83\x01\n\x11UpdateMessageRead\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nstart_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tread_date\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xa9\x01\n\x15UpdateMessageReadByMe\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nstart_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x42\n\x0eunread_counter\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\"\xd1\x01\n\x13UpdateMessageDelete\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12.\n\x04mids\x18\x03 \x03(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x07\x63ounter\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x61\x63tion_date\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"`\n\x0fUpdateChatClear\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x61\x63tion_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"a\n\x10UpdateChatDelete\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x61\x63tion_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\">\n\x11UpdateChatArchive\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"N\n\x17UpdateChatGroupsChanged\x12\x33\n\x07\x64ialogs\x18\x01 \x03(\x0b\x32\x13.dialog.DialogGroupB\r\x8a\xea\x30\t\n\x07visible\"\xac\x01\n\x15UpdateReactionsUpdate\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\treactions\x18\x03 \x03(\x0b\x32\x17.dialog.MessageReactionB\r\x8a\xea\x30\t\n\x07visible\"\xdd\x01\n\x1bUpdateMessageRejectedByHook\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06hookId\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x06reason\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xf4\x01\n\x1fUpdateMessageEditRejectedByHook\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06hookId\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x06reason\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"D\n\x12ReferencedMessages\x12.\n\x04mids\x18\x01 \x03(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07\x63ompact\"\x86\x05\n\x0eHistoryMessage\x12!\n\nsender_uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\x0bsender_peer\x18\x0f \x01(\x0b\x32\x0f.dialog.OutPeer\x12\x31\n\thost_peer\x18\x0c \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\n \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x08prev_mid\x18\x11 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07message\x18\x05 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12\x32\n\x05state\x18\x06 \x01(\x0e\x32\x14.dialog.MessageStateB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\treactions\x18\x07 \x03(\x0b\x32\x17.dialog.MessageReactionB\r\x8a\xea\x30\t\n\x07visible\x12;\n\tattribute\x18\x08 \x01(\x0b\x32\x19.dialog.MessageAttributesB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x07\x66orward\x18\r \x01(\x0b\x32\x1a.dialog.ReferencedMessagesH\x00\x12+\n\x05reply\x18\x0e \x01(\x0b\x32\x1a.dialog.ReferencedMessagesH\x00\x12=\n\tedited_at\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visibleB\x08\n\x06\x61ttach\"\x95\x02\n\x12RequestLoadHistory\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\tload_mode\x18\x05 \x01(\x0e\x32\x14.dialog.ListLoadModeB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x06 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb1\x02\n\x13ResponseLoadHistory\x12\'\n\x07history\x18\x01 \x03(\x0b\x32\x16.dialog.HistoryMessage\x12\x1b\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.User\x12\'\n\nuser_peers\x18\x04 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12\x1d\n\x06groups\x18\x05 \x03(\x0b\x32\r.dialog.Group\x12)\n\x0bgroup_peers\x18\x06 \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12,\n\x07\x63ounter\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x14\n\x0c\x63ounter_date\x18\x08 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xef\x04\n\x06\x44ialog\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0cunread_count\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tsort_date\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsender_uid\x18\x05 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0cis_favourite\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x0c \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x07 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07message\x18\x08 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x05state\x18\t \x01(\x0e\x32\x14.dialog.MessageState\x12(\n\x11\x66irst_unread_date\x18\n \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12<\n\nattributes\x18\x0b \x01(\x0b\x32\x19.dialog.MessageAttributesB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0fpinned_messages\x18\x0e \x01(\x0b\x32\x16.dialog.PinnedMessagesB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0fhistory_message\x18\x0f \x01(\x0b\x32\x16.dialog.HistoryMessageB\r\x8a\xea\x30\t\n\x07visible\"\x9e\x02\n\x12RequestLoadDialogs\x12\x1f\n\x08min_date\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x07\x66ilters\x18\x04 \x03(\x0e\x32\x15.dialog.DialogsFilterB\r\x8a\xea\x30\t\n\x07visible\x12\x32\n\rpeers_to_load\x18\x05 \x03(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xe5\x01\n\x13ResponseLoadDialogs\x12\x1d\n\x06groups\x18\x01 \x03(\x0b\x32\r.dialog.Group\x12\x1b\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.User\x12\x1f\n\x07\x64ialogs\x18\x03 \x03(\x0b\x32\x0e.dialog.Dialog\x12\'\n\nuser_peers\x18\x04 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x0bgroup_peers\x18\x05 \x03(\x0b\x32\x14.dialog.GroupOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"Z\n\x0b\x44ialogIndex\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\ttimestamp\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"7\n\x17RequestFetchDialogIndex:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"f\n\x18ResponseFetchDialogIndex\x12+\n\x0e\x64ialog_indices\x18\x01 \x03(\x0b\x32\x13.dialog.DialogIndex:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xd4\x01\n\x13RequestLoadArchived\x12?\n\x0bnext_offset\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x1c\n\x05limit\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x98\x02\n\x14ResponseLoadArchived\x12\x1d\n\x06groups\x18\x01 \x03(\x0b\x32\r.dialog.Group\x12\x1b\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.User\x12\x1f\n\x07\x64ialogs\x18\x03 \x03(\x0b\x32\x0e.dialog.Dialog\x12\'\n\nuser_peers\x18\x05 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x0bgroup_peers\x18\x06 \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12\x30\n\x0bnext_offset\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"l\n\x19RequestLoadGroupedDialogs\x12\x31\n\roptimizations\x18\x01 \x03(\x0e\x32\x1a.dialog.UpdateOptimization:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xd5\x02\n\x1aResponseLoadGroupedDialogs\x12$\n\x07\x64ialogs\x18\x01 \x03(\x0b\x32\x13.dialog.DialogGroup\x12\x1b\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.User\x12\x1d\n\x06groups\x18\x03 \x03(\x0b\x32\r.dialog.Group\x12\x31\n\rshow_archived\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0bshow_invite\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\nuser_peers\x18\x06 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x0bgroup_peers\x18\x07 \x03(\x0b\x32\x14.dialog.GroupOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa3\x01\n\x14ResponseDialogsOrder\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12\x32\n\x06groups\x18\x03 \x03(\x0b\x32\x13.dialog.DialogGroupB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"_\n\x11RequestHideDialog\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"P\n\x11RequestShowDialog\x12\x1d\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeer:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"d\n\x16RequestFavouriteDialog\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"f\n\x18RequestUnfavouriteDialog\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8a\x01\n\x1cUpdateDialogFavouriteChanged\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0cis_favourite\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"g\n\x19RequestNotifyDialogOpened\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"@\n\x0ePinnedMessages\x12.\n\x04mids\x18\x01 \x03(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\"\xb4\x01\n\x11RequestPinMessage\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12$\n\rlast_pin_date\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb6\x01\n\x13RequestUnpinMessage\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12$\n\rlast_pin_date\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xac\x01\n\x1bUpdatePinnedMessagesChanged\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0fpinned_messages\x18\x02 \x01(\x0b\x32\x16.dialog.PinnedMessagesB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x61\x63tion_date\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible*\xa2\x01\n\x15InteractiveMediaStyle\x12!\n\x1dINTERACTIVEMEDIASTYLE_UNKNOWN\x10\x00\x12!\n\x1dINTERACTIVEMEDIASTYLE_DEFAULT\x10\x01\x12!\n\x1dINTERACTIVEMEDIASTYLE_PRIMARY\x10\x02\x12 \n\x1cINTERACTIVEMEDIASTYLE_DANGER\x10\x03*q\n\x0cMessageState\x12\x18\n\x14MESSAGESTATE_UNKNOWN\x10\x00\x12\x15\n\x11MESSAGESTATE_SENT\x10\x01\x12\x19\n\x15MESSAGESTATE_RECEIVED\x10\x02\x12\x15\n\x11MESSAGESTATE_READ\x10\x03*t\n\x0cListLoadMode\x12\x18\n\x14LISTLOADMODE_UNKNOWN\x10\x00\x12\x18\n\x14LISTLOADMODE_FORWARD\x10\x01\x12\x19\n\x15LISTLOADMODE_BACKWARD\x10\x02\x12\x15\n\x11LISTLOADMODE_BOTH\x10\x03*r\n\rDialogsFilter\x12\x19\n\x15\x44IALOGSFILTER_UNKNOWN\x10\x00\x12#\n\x1f\x44IALOGSFILTER_EXCLUDEFAVOURITES\x10\x01\x12!\n\x1d\x44IALOGSFILTER_EXCLUDEARCHIVED\x10\x02\x32\x91\x16\n\tMessaging\x12\x91\x01\n\x18\x44oInteractiveMediaAction\x12\'.dialog.RequestDoInteractiveMediaAction\x1a\x14.dialog.ResponseVoid\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/grpc/Messaging/DoInteractiveMediaAction:\x01*\x12q\n\x0bSendMessage\x12\x1a.dialog.RequestSendMessage\x1a\x1b.dialog.ResponseSendMessage\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Messaging/SendMessage:\x01*\x12s\n\rUpdateMessage\x12\x1c.dialog.RequestUpdateMessage\x1a\x17.dialog.ResponseSeqDate\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Messaging/UpdateMessage:\x01*\x12v\n\x0fMessageReceived\x12\x1e.dialog.RequestMessageReceived\x1a\x14.dialog.ResponseVoid\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Messaging/MessageReceived:\x01*\x12j\n\x0bMessageRead\x12\x1a.dialog.RequestMessageRead\x1a\x14.dialog.ResponseVoid\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Messaging/MessageRead:\x01*\x12\x87\x01\n\x15\x44\x65leteMessageObsolete\x12$.dialog.RequestDeleteMessageObsolete\x1a\x13.dialog.ResponseSeq\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Messaging/DeleteMessageObsolete:\x01*\x12\x63\n\tClearChat\x12\x18.dialog.RequestClearChat\x1a\x13.dialog.ResponseSeq\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Messaging/ClearChat:\x01*\x12\x66\n\nDeleteChat\x12\x19.dialog.RequestDeleteChat\x1a\x13.dialog.ResponseSeq\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Messaging/DeleteChat:\x01*\x12i\n\x0b\x41rchiveChat\x12\x1a.dialog.RequestArchiveChat\x1a\x13.dialog.ResponseSeq\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Messaging/ArchiveChat:\x01*\x12\x8c\x01\n\x12MessageSetReaction\x12!.dialog.RequestMessageSetReaction\x1a!.dialog.ResponseReactionsResponse\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Messaging/MessageSetReaction:\x01*\x12\x95\x01\n\x15MessageRemoveReaction\x12$.dialog.RequestMessageRemoveReaction\x1a!.dialog.ResponseReactionsResponse\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Messaging/MessageRemoveReaction:\x01*\x12q\n\x0bLoadHistory\x12\x1a.dialog.RequestLoadHistory\x1a\x1b.dialog.ResponseLoadHistory\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Messaging/LoadHistory:\x01*\x12q\n\x0bLoadDialogs\x12\x1a.dialog.RequestLoadDialogs\x1a\x1b.dialog.ResponseLoadDialogs\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Messaging/LoadDialogs:\x01*\x12\x85\x01\n\x10\x46\x65tchDialogIndex\x12\x1f.dialog.RequestFetchDialogIndex\x1a .dialog.ResponseFetchDialogIndex\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/Messaging/FetchDialogIndex:\x01*\x12u\n\x0cLoadArchived\x12\x1b.dialog.RequestLoadArchived\x1a\x1c.dialog.ResponseLoadArchived\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Messaging/LoadArchived:\x01*\x12\x8d\x01\n\x12LoadGroupedDialogs\x12!.dialog.RequestLoadGroupedDialogs\x1a\".dialog.ResponseLoadGroupedDialogs\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Messaging/LoadGroupedDialogs:\x01*\x12o\n\nHideDialog\x12\x19.dialog.RequestHideDialog\x1a\x1c.dialog.ResponseDialogsOrder\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Messaging/HideDialog:\x01*\x12o\n\nShowDialog\x12\x19.dialog.RequestShowDialog\x1a\x1c.dialog.ResponseDialogsOrder\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Messaging/ShowDialog:\x01*\x12~\n\x0f\x46\x61vouriteDialog\x12\x1e.dialog.RequestFavouriteDialog\x1a\x1c.dialog.ResponseDialogsOrder\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Messaging/FavouriteDialog:\x01*\x12\x84\x01\n\x11UnfavouriteDialog\x12 .dialog.RequestUnfavouriteDialog\x1a\x1c.dialog.ResponseDialogsOrder\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Messaging/UnfavouriteDialog:\x01*\x12\x7f\n\x12NotifyDialogOpened\x12!.dialog.RequestNotifyDialogOpened\x1a\x14.dialog.ResponseVoid\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Messaging/NotifyDialogOpened:\x01*\x12j\n\nPinMessage\x12\x19.dialog.RequestPinMessage\x1a\x17.dialog.ResponseSeqDate\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Messaging/PinMessage:\x01*\x12p\n\x0cUnpinMessage\x12\x1b.dialog.RequestUnpinMessage\x1a\x17.dialog.ResponseSeqDate\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Messaging/UnpinMessage:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_INTERACTIVEMEDIASTYLE = _descriptor.EnumDescriptor(
  name='InteractiveMediaStyle',
  full_name='dialog.InteractiveMediaStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTERACTIVEMEDIASTYLE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERACTIVEMEDIASTYLE_DEFAULT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERACTIVEMEDIASTYLE_PRIMARY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERACTIVEMEDIASTYLE_DANGER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18521,
  serialized_end=18683,
)
_sym_db.RegisterEnumDescriptor(_INTERACTIVEMEDIASTYLE)

InteractiveMediaStyle = enum_type_wrapper.EnumTypeWrapper(_INTERACTIVEMEDIASTYLE)
_MESSAGESTATE = _descriptor.EnumDescriptor(
  name='MessageState',
  full_name='dialog.MessageState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGESTATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MESSAGESTATE_SENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MESSAGESTATE_RECEIVED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MESSAGESTATE_READ', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18685,
  serialized_end=18798,
)
_sym_db.RegisterEnumDescriptor(_MESSAGESTATE)

MessageState = enum_type_wrapper.EnumTypeWrapper(_MESSAGESTATE)
_LISTLOADMODE = _descriptor.EnumDescriptor(
  name='ListLoadMode',
  full_name='dialog.ListLoadMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LISTLOADMODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTLOADMODE_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTLOADMODE_BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTLOADMODE_BOTH', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18800,
  serialized_end=18916,
)
_sym_db.RegisterEnumDescriptor(_LISTLOADMODE)

ListLoadMode = enum_type_wrapper.EnumTypeWrapper(_LISTLOADMODE)
_DIALOGSFILTER = _descriptor.EnumDescriptor(
  name='DialogsFilter',
  full_name='dialog.DialogsFilter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DIALOGSFILTER_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIALOGSFILTER_EXCLUDEFAVOURITES', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIALOGSFILTER_EXCLUDEARCHIVED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18918,
  serialized_end=19032,
)
_sym_db.RegisterEnumDescriptor(_DIALOGSFILTER)

DialogsFilter = enum_type_wrapper.EnumTypeWrapper(_DIALOGSFILTER)
INTERACTIVEMEDIASTYLE_UNKNOWN = 0
INTERACTIVEMEDIASTYLE_DEFAULT = 1
INTERACTIVEMEDIASTYLE_PRIMARY = 2
INTERACTIVEMEDIASTYLE_DANGER = 3
MESSAGESTATE_UNKNOWN = 0
MESSAGESTATE_SENT = 1
MESSAGESTATE_RECEIVED = 2
MESSAGESTATE_READ = 3
LISTLOADMODE_UNKNOWN = 0
LISTLOADMODE_FORWARD = 1
LISTLOADMODE_BACKWARD = 2
LISTLOADMODE_BOTH = 3
DIALOGSFILTER_UNKNOWN = 0
DIALOGSFILTER_EXCLUDEFAVOURITES = 1
DIALOGSFILTER_EXCLUDEARCHIVED = 2



_MESSAGEATTRIBUTES = _descriptor.Descriptor(
  name='MessageAttributes',
  full_name='dialog.MessageAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_mentioned', full_name='dialog.MessageAttributes.is_mentioned', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_highlighted', full_name='dialog.MessageAttributes.is_highlighted', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_notified', full_name='dialog.MessageAttributes.is_notified', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_only_for_you', full_name='dialog.MessageAttributes.is_only_for_you', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=499,
)


_QUOTEDMESSAGE = _descriptor.Descriptor(
  name='QuotedMessage',
  full_name='dialog.QuotedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='dialog.QuotedMessage.message_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_group_id', full_name='dialog.QuotedMessage.public_group_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_user_id', full_name='dialog.QuotedMessage.sender_user_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_date', full_name='dialog.QuotedMessage.message_date', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quoted_message_content', full_name='dialog.QuotedMessage.quoted_message_content', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=739,
)


_MESSAGEMEDIA = _descriptor.Descriptor(
  name='MessageMedia',
  full_name='dialog.MessageMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='webpage', full_name='dialog.MessageMedia.webpage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='dialog.MessageMedia.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='dialog.MessageMedia.audio', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actions', full_name='dialog.MessageMedia.actions', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=742,
  serialized_end=973,
)


_WEBPAGEMEDIA = _descriptor.Descriptor(
  name='WebpageMedia',
  full_name='dialog.WebpageMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.WebpageMedia.url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.WebpageMedia.title', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.WebpageMedia.description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='dialog.WebpageMedia.image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1224,
)


_IMAGEMEDIA = _descriptor.Descriptor(
  name='ImageMedia',
  full_name='dialog.ImageMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='dialog.ImageMedia.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1226,
  serialized_end=1291,
)


_AUDIOMEDIA = _descriptor.Descriptor(
  name='AudioMedia',
  full_name='dialog.AudioMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='dialog.AudioMedia.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1358,
)


_INTERACTIVEMEDIAWIDGET = _descriptor.Descriptor(
  name='InteractiveMediaWidget',
  full_name='dialog.InteractiveMediaWidget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interactiveMediaButton', full_name='dialog.InteractiveMediaWidget.interactiveMediaButton', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interactiveMediaSelect', full_name='dialog.InteractiveMediaWidget.interactiveMediaSelect', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.InteractiveMediaWidget.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1361,
  serialized_end=1525,
)


_INTERACTIVEMEDIABUTTON = _descriptor.Descriptor(
  name='InteractiveMediaButton',
  full_name='dialog.InteractiveMediaButton',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.InteractiveMediaButton.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='dialog.InteractiveMediaButton.label', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1641,
)


_INTERACTIVEMEDIASELECT = _descriptor.Descriptor(
  name='InteractiveMediaSelect',
  full_name='dialog.InteractiveMediaSelect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='dialog.InteractiveMediaSelect.options', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='dialog.InteractiveMediaSelect.label', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='dialog.InteractiveMediaSelect.default_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1866,
)


_INTERACTIVEMEDIASELECTOPTION = _descriptor.Descriptor(
  name='InteractiveMediaSelectOption',
  full_name='dialog.InteractiveMediaSelectOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.InteractiveMediaSelectOption.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='dialog.InteractiveMediaSelectOption.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1868,
  serialized_end=1958,
)


_INTERACTIVEMEDIA = _descriptor.Descriptor(
  name='InteractiveMedia',
  full_name='dialog.InteractiveMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.InteractiveMedia.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widget', full_name='dialog.InteractiveMedia.widget', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='dialog.InteractiveMedia.style', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirm', full_name='dialog.InteractiveMedia.confirm', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1961,
  serialized_end=2195,
)


_INTERACTIVEMEDIATRANSLATION = _descriptor.Descriptor(
  name='InteractiveMediaTranslation',
  full_name='dialog.InteractiveMediaTranslation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.InteractiveMediaTranslation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.InteractiveMediaTranslation.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2197,
  serialized_end=2283,
)


_INTERACTIVEMEDIATRANSLATIONGROUP = _descriptor.Descriptor(
  name='InteractiveMediaTranslationGroup',
  full_name='dialog.InteractiveMediaTranslationGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='dialog.InteractiveMediaTranslationGroup.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages', full_name='dialog.InteractiveMediaTranslationGroup.messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2423,
)


_INTERACTIVEMEDIAGROUP = _descriptor.Descriptor(
  name='InteractiveMediaGroup',
  full_name='dialog.InteractiveMediaGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='dialog.InteractiveMediaGroup.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.InteractiveMediaGroup.title', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.InteractiveMediaGroup.description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='translations', full_name='dialog.InteractiveMediaGroup.translations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2426,
  serialized_end=2710,
)


_INTERACTIVEMEDIACONFIRM = _descriptor.Descriptor(
  name='InteractiveMediaConfirm',
  full_name='dialog.InteractiveMediaConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.InteractiveMediaConfirm.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.InteractiveMediaConfirm.title', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ok', full_name='dialog.InteractiveMediaConfirm.ok', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dismiss', full_name='dialog.InteractiveMediaConfirm.dismiss', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2713,
  serialized_end=2976,
)


_UPDATEINTERACTIVEMEDIAEVENT = _descriptor.Descriptor(
  name='UpdateInteractiveMediaEvent',
  full_name='dialog.UpdateInteractiveMediaEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateInteractiveMediaEvent.mid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateInteractiveMediaEvent.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.UpdateInteractiveMediaEvent.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateInteractiveMediaEvent.uid', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3140,
)


_REQUESTDOINTERACTIVEMEDIAACTION = _descriptor.Descriptor(
  name='RequestDoInteractiveMediaAction',
  full_name='dialog.RequestDoInteractiveMediaAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestDoInteractiveMediaAction.mid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestDoInteractiveMediaAction.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.RequestDoInteractiveMediaAction.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3143,
  serialized_end=3310,
)


_MESSAGECONTENT = _descriptor.Descriptor(
  name='MessageContent',
  full_name='dialog.MessageContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='textMessage', full_name='dialog.MessageContent.textMessage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceMessage', full_name='dialog.MessageContent.serviceMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='documentMessage', full_name='dialog.MessageContent.documentMessage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jsonMessage', full_name='dialog.MessageContent.jsonMessage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsupportedMessage', full_name='dialog.MessageContent.unsupportedMessage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stickerMessage', full_name='dialog.MessageContent.stickerMessage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binaryMessage', full_name='dialog.MessageContent.binaryMessage', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emptyMessage', full_name='dialog.MessageContent.emptyMessage', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deletedMessage', full_name='dialog.MessageContent.deletedMessage', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.MessageContent.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3313,
  serialized_end=3779,
)


_TEXTMESSAGE = _descriptor.Descriptor(
  name='TextMessage',
  full_name='dialog.TextMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.TextMessage.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mentions', full_name='dialog.TextMessage.mentions', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='dialog.TextMessage.ext', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media', full_name='dialog.TextMessage.media', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='dialog.TextMessage.extensions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3782,
  serialized_end=4007,
)


_TEXTMESSAGEEX = _descriptor.Descriptor(
  name='TextMessageEx',
  full_name='dialog.TextMessageEx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='textExMarkdown', full_name='dialog.TextMessageEx.textExMarkdown', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textModernMessage', full_name='dialog.TextMessageEx.textModernMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textCommand', full_name='dialog.TextMessageEx.textCommand', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.TextMessageEx.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4010,
  serialized_end=4183,
)


_TEXTEXMARKDOWN = _descriptor.Descriptor(
  name='TextExMarkdown',
  full_name='dialog.TextExMarkdown',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='markdown', full_name='dialog.TextExMarkdown.markdown', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4185,
  serialized_end=4233,
)


_TEXTMODERNMESSAGE = _descriptor.Descriptor(
  name='TextModernMessage',
  full_name='dialog.TextModernMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.TextModernMessage.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_name_override', full_name='dialog.TextModernMessage.sender_name_override', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_photo_override', full_name='dialog.TextModernMessage.sender_photo_override', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='dialog.TextModernMessage.style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attaches', full_name='dialog.TextModernMessage.attaches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4236,
  serialized_end=4563,
)


_PARAGRAPHSTYLE = _descriptor.Descriptor(
  name='ParagraphStyle',
  full_name='dialog.ParagraphStyle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='show_paragraph', full_name='dialog.ParagraphStyle.show_paragraph', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_color', full_name='dialog.ParagraphStyle.paragraph_color', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bg_color', full_name='dialog.ParagraphStyle.bg_color', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4566,
  serialized_end=4752,
)


_TEXTMODERNATTACH = _descriptor.Descriptor(
  name='TextModernAttach',
  full_name='dialog.TextModernAttach',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.TextModernAttach.title', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_url', full_name='dialog.TextModernAttach.title_url', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_icon', full_name='dialog.TextModernAttach.title_icon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.TextModernAttach.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='dialog.TextModernAttach.style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='dialog.TextModernAttach.fields', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4755,
  serialized_end=5107,
)


_TEXTMODERNFIELD = _descriptor.Descriptor(
  name='TextModernField',
  full_name='dialog.TextModernField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.TextModernField.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.TextModernField.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_short', full_name='dialog.TextModernField.is_short', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5110,
  serialized_end=5248,
)


_TEXTCOMMAND = _descriptor.Descriptor(
  name='TextCommand',
  full_name='dialog.TextCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='dialog.TextCommand.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='dialog.TextCommand.args', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5250,
  serialized_end=5324,
)


_SERVICEMESSAGE = _descriptor.Descriptor(
  name='ServiceMessage',
  full_name='dialog.ServiceMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.ServiceMessage.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='dialog.ServiceMessage.ext', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5326,
  serialized_end=5417,
)


_SERVICEEX = _descriptor.Descriptor(
  name='ServiceEx',
  full_name='dialog.ServiceEx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userInvited', full_name='dialog.ServiceEx.userInvited', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userJoined', full_name='dialog.ServiceEx.userJoined', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userKicked', full_name='dialog.ServiceEx.userKicked', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userLeft', full_name='dialog.ServiceEx.userLeft', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupCreated', full_name='dialog.ServiceEx.groupCreated', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedTitle', full_name='dialog.ServiceEx.changedTitle', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedTopic', full_name='dialog.ServiceEx.changedTopic', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedAbout', full_name='dialog.ServiceEx.changedAbout', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedAvatar', full_name='dialog.ServiceEx.changedAvatar', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contactRegistered', full_name='dialog.ServiceEx.contactRegistered', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phoneMissed', full_name='dialog.ServiceEx.phoneMissed', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phoneCall', full_name='dialog.ServiceEx.phoneCall', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phoneRejected', full_name='dialog.ServiceEx.phoneRejected', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatArchived', full_name='dialog.ServiceEx.chatArchived', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatRestored', full_name='dialog.ServiceEx.chatRestored', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.ServiceEx.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5420,
  serialized_end=6252,
)


_SERVICEEXUSERINVITED = _descriptor.Descriptor(
  name='ServiceExUserInvited',
  full_name='dialog.ServiceExUserInvited',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invited_uid', full_name='dialog.ServiceExUserInvited.invited_uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6254,
  serialized_end=6312,
)


_SERVICEEXUSERJOINED = _descriptor.Descriptor(
  name='ServiceExUserJoined',
  full_name='dialog.ServiceExUserJoined',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6314,
  serialized_end=6335,
)


_SERVICEEXUSERKICKED = _descriptor.Descriptor(
  name='ServiceExUserKicked',
  full_name='dialog.ServiceExUserKicked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kicked_uid', full_name='dialog.ServiceExUserKicked.kicked_uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6337,
  serialized_end=6393,
)


_SERVICEEXUSERLEFT = _descriptor.Descriptor(
  name='ServiceExUserLeft',
  full_name='dialog.ServiceExUserLeft',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6395,
  serialized_end=6414,
)


_SERVICEEXGROUPCREATED = _descriptor.Descriptor(
  name='ServiceExGroupCreated',
  full_name='dialog.ServiceExGroupCreated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6416,
  serialized_end=6439,
)


_SERVICEEXCHANGEDTITLE = _descriptor.Descriptor(
  name='ServiceExChangedTitle',
  full_name='dialog.ServiceExChangedTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.ServiceExChangedTitle.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6441,
  serialized_end=6493,
)


_SERVICEEXCHANGEDTOPIC = _descriptor.Descriptor(
  name='ServiceExChangedTopic',
  full_name='dialog.ServiceExChangedTopic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='dialog.ServiceExChangedTopic.topic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6495,
  serialized_end=6577,
)


_SERVICEEXCHANGEDABOUT = _descriptor.Descriptor(
  name='ServiceExChangedAbout',
  full_name='dialog.ServiceExChangedAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.ServiceExChangedAbout.about', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6579,
  serialized_end=6661,
)


_SERVICEEXCHANGEDAVATAR = _descriptor.Descriptor(
  name='ServiceExChangedAvatar',
  full_name='dialog.ServiceExChangedAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.ServiceExChangedAvatar.avatar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6663,
  serialized_end=6734,
)


_SERVICEEXCONTACTREGISTERED = _descriptor.Descriptor(
  name='ServiceExContactRegistered',
  full_name='dialog.ServiceExContactRegistered',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.ServiceExContactRegistered.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6736,
  serialized_end=6792,
)


_SERVICEEXPHONEMISSED = _descriptor.Descriptor(
  name='ServiceExPhoneMissed',
  full_name='dialog.ServiceExPhoneMissed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6794,
  serialized_end=6816,
)


_SERVICEEXPHONECALL = _descriptor.Descriptor(
  name='ServiceExPhoneCall',
  full_name='dialog.ServiceExPhoneCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.ServiceExPhoneCall.duration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6818,
  serialized_end=6871,
)


_SERVICEEXPHONEREJECTED = _descriptor.Descriptor(
  name='ServiceExPhoneRejected',
  full_name='dialog.ServiceExPhoneRejected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6873,
  serialized_end=6897,
)


_SERVICEEXCHATARCHIVED = _descriptor.Descriptor(
  name='ServiceExChatArchived',
  full_name='dialog.ServiceExChatArchived',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6899,
  serialized_end=6922,
)


_SERVICEEXCHATRESTORED = _descriptor.Descriptor(
  name='ServiceExChatRestored',
  full_name='dialog.ServiceExChatRestored',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6924,
  serialized_end=6947,
)


_DOCUMENTMESSAGE = _descriptor.Descriptor(
  name='DocumentMessage',
  full_name='dialog.DocumentMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='dialog.DocumentMessage.file_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.DocumentMessage.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='dialog.DocumentMessage.file_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.DocumentMessage.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='dialog.DocumentMessage.mime_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumb', full_name='dialog.DocumentMessage.thumb', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='dialog.DocumentMessage.ext', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6950,
  serialized_end=7227,
)


_DOCUMENTEX = _descriptor.Descriptor(
  name='DocumentEx',
  full_name='dialog.DocumentEx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='photo', full_name='dialog.DocumentEx.photo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video', full_name='dialog.DocumentEx.video', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voice', full_name='dialog.DocumentEx.voice', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.DocumentEx.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=7230,
  serialized_end=7376,
)


_DOCUMENTEXPHOTO = _descriptor.Descriptor(
  name='DocumentExPhoto',
  full_name='dialog.DocumentExPhoto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='w', full_name='dialog.DocumentExPhoto.w', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h', full_name='dialog.DocumentExPhoto.h', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7378,
  serialized_end=7447,
)


_DOCUMENTEXVIDEO = _descriptor.Descriptor(
  name='DocumentExVideo',
  full_name='dialog.DocumentExVideo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='w', full_name='dialog.DocumentExVideo.w', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h', full_name='dialog.DocumentExVideo.h', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.DocumentExVideo.duration', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7449,
  serialized_end=7551,
)


_DOCUMENTEXVOICE = _descriptor.Descriptor(
  name='DocumentExVoice',
  full_name='dialog.DocumentExVoice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.DocumentExVoice.duration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7553,
  serialized_end=7603,
)


_JSONMESSAGE = _descriptor.Descriptor(
  name='JsonMessage',
  full_name='dialog.JsonMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_json', full_name='dialog.JsonMessage.raw_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7605,
  serialized_end=7650,
)


_UNSUPPORTEDMESSAGE = _descriptor.Descriptor(
  name='UnsupportedMessage',
  full_name='dialog.UnsupportedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7652,
  serialized_end=7672,
)


_STICKERMESSAGE = _descriptor.Descriptor(
  name='StickerMessage',
  full_name='dialog.StickerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sticker_id', full_name='dialog.StickerMessage.sticker_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fast_preview', full_name='dialog.StickerMessage.fast_preview', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_512', full_name='dialog.StickerMessage.image_512', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_256', full_name='dialog.StickerMessage.image_256', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sticker_collection_id', full_name='dialog.StickerMessage.sticker_collection_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sticker_collection_access_hash', full_name='dialog.StickerMessage.sticker_collection_access_hash', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emoji', full_name='dialog.StickerMessage.emoji', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7675,
  serialized_end=8153,
)


_BINARYMESSAGE = _descriptor.Descriptor(
  name='BinaryMessage',
  full_name='dialog.BinaryMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_tag', full_name='dialog.BinaryMessage.content_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='dialog.BinaryMessage.msg', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8155,
  serialized_end=8234,
)


_EMPTYMESSAGE = _descriptor.Descriptor(
  name='EmptyMessage',
  full_name='dialog.EmptyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8236,
  serialized_end=8250,
)


_DELETEDMESSAGE = _descriptor.Descriptor(
  name='DeletedMessage',
  full_name='dialog.DeletedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_local', full_name='dialog.DeletedMessage.is_local', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8252,
  serialized_end=8329,
)


_DIALOGSHORT = _descriptor.Descriptor(
  name='DialogShort',
  full_name='dialog.DialogShort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.DialogShort.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter', full_name='dialog.DialogShort.counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.DialogShort.date', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8331,
  serialized_end=8448,
)


_DIALOGGROUP = _descriptor.Descriptor(
  name='DialogGroup',
  full_name='dialog.DialogGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.DialogGroup.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.DialogGroup.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.DialogGroup.dialogs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8450,
  serialized_end=8573,
)


_MESSAGEREACTION = _descriptor.Descriptor(
  name='MessageReaction',
  full_name='dialog.MessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.MessageReaction.users', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.MessageReaction.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8575,
  serialized_end=8651,
)


_SEARCHPREDICATE = _descriptor.Descriptor(
  name='SearchPredicate',
  full_name='dialog.SearchPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.SearchPredicate.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='dialog.SearchPredicate.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8653,
  serialized_end=8729,
)


_REQUESTSENDMESSAGE = _descriptor.Descriptor(
  name='RequestSendMessage',
  full_name='dialog.RequestSendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestSendMessage.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deduplication_id', full_name='dialog.RequestSendMessage.deduplication_id', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.RequestSendMessage.message', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_only_for_user', full_name='dialog.RequestSendMessage.is_only_for_user', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward', full_name='dialog.RequestSendMessage.forward', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply', full_name='dialog.RequestSendMessage.reply', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicates', full_name='dialog.RequestSendMessage.predicates', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='white_list', full_name='dialog.RequestSendMessage.white_list', index=7,
      number=11, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='black_list', full_name='dialog.RequestSendMessage.black_list', index=8,
      number=12, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8732,
  serialized_end=9214,
)


_REQUESTUPDATEMESSAGE = _descriptor.Descriptor(
  name='RequestUpdateMessage',
  full_name='dialog.RequestUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestUpdateMessage.mid', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_message', full_name='dialog.RequestUpdateMessage.updated_message', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_edited_at', full_name='dialog.RequestUpdateMessage.last_edited_at', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9217,
  serialized_end=9419,
)


_REQUESTMESSAGERECEIVED = _descriptor.Descriptor(
  name='RequestMessageReceived',
  full_name='dialog.RequestMessageReceived',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestMessageReceived.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.RequestMessageReceived.date', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9422,
  serialized_end=9551,
)


_REQUESTMESSAGEREAD = _descriptor.Descriptor(
  name='RequestMessageRead',
  full_name='dialog.RequestMessageRead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestMessageRead.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.RequestMessageRead.date', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9553,
  serialized_end=9678,
)


_REQUESTDELETEMESSAGEOBSOLETE = _descriptor.Descriptor(
  name='RequestDeleteMessageObsolete',
  full_name='dialog.RequestDeleteMessageObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mids', full_name='dialog.RequestDeleteMessageObsolete.mids', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9680,
  serialized_end=9788,
)


_REQUESTCLEARCHAT = _descriptor.Descriptor(
  name='RequestClearChat',
  full_name='dialog.RequestClearChat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestClearChat.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_message_date', full_name='dialog.RequestClearChat.last_message_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9791,
  serialized_end=9927,
)


_REQUESTDELETECHAT = _descriptor.Descriptor(
  name='RequestDeleteChat',
  full_name='dialog.RequestDeleteChat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestDeleteChat.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_message_date', full_name='dialog.RequestDeleteChat.last_message_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9930,
  serialized_end=10067,
)


_REQUESTARCHIVECHAT = _descriptor.Descriptor(
  name='RequestArchiveChat',
  full_name='dialog.RequestArchiveChat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestArchiveChat.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10069,
  serialized_end=10165,
)


_REQUESTMESSAGESETREACTION = _descriptor.Descriptor(
  name='RequestMessageSetReaction',
  full_name='dialog.RequestMessageSetReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestMessageSetReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestMessageSetReaction.mid', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.RequestMessageSetReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10168,
  serialized_end=10347,
)


_REQUESTMESSAGEREMOVEREACTION = _descriptor.Descriptor(
  name='RequestMessageRemoveReaction',
  full_name='dialog.RequestMessageRemoveReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestMessageRemoveReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestMessageRemoveReaction.mid', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.RequestMessageRemoveReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10350,
  serialized_end=10532,
)


_RESPONSEREACTIONSRESPONSE = _descriptor.Descriptor(
  name='ResponseReactionsResponse',
  full_name='dialog.ResponseReactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseReactionsResponse.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseReactionsResponse.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='dialog.ResponseReactionsResponse.reactions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10535,
  serialized_end=10665,
)


_RESPONSESENDMESSAGE = _descriptor.Descriptor(
  name='ResponseSendMessage',
  full_name='dialog.ResponseSendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseSendMessage.mid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10667,
  serialized_end=10766,
)


_UPDATEMESSAGE = _descriptor.Descriptor(
  name='UpdateMessage',
  full_name='dialog.UpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessage.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_uid', full_name='dialog.UpdateMessage.sender_uid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateMessage.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateMessage.mid', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.UpdateMessage.message', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='dialog.UpdateMessage.attributes', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward', full_name='dialog.UpdateMessage.forward', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply', full_name='dialog.UpdateMessage.reply', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_mid', full_name='dialog.UpdateMessage.previous_mid', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter', full_name='dialog.UpdateMessage.counter', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='attach', full_name='dialog.UpdateMessage.attach',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=10769,
  serialized_end=11305,
)


_UPDATEMESSAGECONTENTCHANGED = _descriptor.Descriptor(
  name='UpdateMessageContentChanged',
  full_name='dialog.UpdateMessageContentChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageContentChanged.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateMessageContentChanged.mid', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.UpdateMessageContentChanged.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edited_at', full_name='dialog.UpdateMessageContentChanged.edited_at', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11308,
  serialized_end=11517,
)


_UPDATEMESSAGESENT = _descriptor.Descriptor(
  name='UpdateMessageSent',
  full_name='dialog.UpdateMessageSent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageSent.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateMessageSent.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateMessageSent.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateMessageSent.mid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_mid', full_name='dialog.UpdateMessageSent.prev_mid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unread_counter', full_name='dialog.UpdateMessageSent.unread_counter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11520,
  serialized_end=11806,
)


_UPDATEMESSAGERECEIVED = _descriptor.Descriptor(
  name='UpdateMessageReceived',
  full_name='dialog.UpdateMessageReceived',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageReceived.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='dialog.UpdateMessageReceived.start_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='received_date', full_name='dialog.UpdateMessageReceived.received_date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11809,
  serialized_end=11948,
)


_UPDATEMESSAGEREAD = _descriptor.Descriptor(
  name='UpdateMessageRead',
  full_name='dialog.UpdateMessageRead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageRead.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='dialog.UpdateMessageRead.start_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_date', full_name='dialog.UpdateMessageRead.read_date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11951,
  serialized_end=12082,
)


_UPDATEMESSAGEREADBYME = _descriptor.Descriptor(
  name='UpdateMessageReadByMe',
  full_name='dialog.UpdateMessageReadByMe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageReadByMe.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='dialog.UpdateMessageReadByMe.start_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unread_counter', full_name='dialog.UpdateMessageReadByMe.unread_counter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12085,
  serialized_end=12254,
)


_UPDATEMESSAGEDELETE = _descriptor.Descriptor(
  name='UpdateMessageDelete',
  full_name='dialog.UpdateMessageDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageDelete.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mids', full_name='dialog.UpdateMessageDelete.mids', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter', full_name='dialog.UpdateMessageDelete.counter', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_date', full_name='dialog.UpdateMessageDelete.action_date', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12257,
  serialized_end=12466,
)


_UPDATECHATCLEAR = _descriptor.Descriptor(
  name='UpdateChatClear',
  full_name='dialog.UpdateChatClear',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateChatClear.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_date', full_name='dialog.UpdateChatClear.action_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12468,
  serialized_end=12564,
)


_UPDATECHATDELETE = _descriptor.Descriptor(
  name='UpdateChatDelete',
  full_name='dialog.UpdateChatDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateChatDelete.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_date', full_name='dialog.UpdateChatDelete.action_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12566,
  serialized_end=12663,
)


_UPDATECHATARCHIVE = _descriptor.Descriptor(
  name='UpdateChatArchive',
  full_name='dialog.UpdateChatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateChatArchive.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12665,
  serialized_end=12727,
)


_UPDATECHATGROUPSCHANGED = _descriptor.Descriptor(
  name='UpdateChatGroupsChanged',
  full_name='dialog.UpdateChatGroupsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.UpdateChatGroupsChanged.dialogs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12729,
  serialized_end=12807,
)


_UPDATEREACTIONSUPDATE = _descriptor.Descriptor(
  name='UpdateReactionsUpdate',
  full_name='dialog.UpdateReactionsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateReactionsUpdate.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateReactionsUpdate.mid', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='dialog.UpdateReactionsUpdate.reactions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12810,
  serialized_end=12982,
)


_UPDATEMESSAGEREJECTEDBYHOOK = _descriptor.Descriptor(
  name='UpdateMessageRejectedByHook',
  full_name='dialog.UpdateMessageRejectedByHook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageRejectedByHook.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateMessageRejectedByHook.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateMessageRejectedByHook.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hookId', full_name='dialog.UpdateMessageRejectedByHook.hookId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dialog.UpdateMessageRejectedByHook.reason', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12985,
  serialized_end=13206,
)


_UPDATEMESSAGEEDITREJECTEDBYHOOK = _descriptor.Descriptor(
  name='UpdateMessageEditRejectedByHook',
  full_name='dialog.UpdateMessageEditRejectedByHook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateMessageEditRejectedByHook.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateMessageEditRejectedByHook.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateMessageEditRejectedByHook.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hookId', full_name='dialog.UpdateMessageEditRejectedByHook.hookId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dialog.UpdateMessageEditRejectedByHook.reason', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13209,
  serialized_end=13453,
)


_REFERENCEDMESSAGES = _descriptor.Descriptor(
  name='ReferencedMessages',
  full_name='dialog.ReferencedMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mids', full_name='dialog.ReferencedMessages.mids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13455,
  serialized_end=13523,
)


_HISTORYMESSAGE = _descriptor.Descriptor(
  name='HistoryMessage',
  full_name='dialog.HistoryMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_uid', full_name='dialog.HistoryMessage.sender_uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_peer', full_name='dialog.HistoryMessage.sender_peer', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_peer', full_name='dialog.HistoryMessage.host_peer', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.HistoryMessage.mid', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_mid', full_name='dialog.HistoryMessage.prev_mid', index=4,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.HistoryMessage.date', index=5,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.HistoryMessage.message', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.HistoryMessage.state', index=7,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='dialog.HistoryMessage.reactions', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='dialog.HistoryMessage.attribute', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward', full_name='dialog.HistoryMessage.forward', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply', full_name='dialog.HistoryMessage.reply', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edited_at', full_name='dialog.HistoryMessage.edited_at', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='attach', full_name='dialog.HistoryMessage.attach',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=13526,
  serialized_end=14172,
)


_REQUESTLOADHISTORY = _descriptor.Descriptor(
  name='RequestLoadHistory',
  full_name='dialog.RequestLoadHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestLoadHistory.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.RequestLoadHistory.date', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='load_mode', full_name='dialog.RequestLoadHistory.load_mode', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadHistory.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLoadHistory.optimizations', index=4,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14175,
  serialized_end=14452,
)


_RESPONSELOADHISTORY = _descriptor.Descriptor(
  name='ResponseLoadHistory',
  full_name='dialog.ResponseLoadHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='history', full_name='dialog.ResponseLoadHistory.history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadHistory.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadHistory.user_peers', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadHistory.groups', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponseLoadHistory.group_peers', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter', full_name='dialog.ResponseLoadHistory.counter', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter_date', full_name='dialog.ResponseLoadHistory.counter_date', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14455,
  serialized_end=14760,
)


_DIALOG = _descriptor.Descriptor(
  name='Dialog',
  full_name='dialog.Dialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.Dialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unread_count', full_name='dialog.Dialog.unread_count', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_date', full_name='dialog.Dialog.sort_date', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_uid', full_name='dialog.Dialog.sender_uid', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_favourite', full_name='dialog.Dialog.is_favourite', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.Dialog.mid', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.Dialog.date', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.Dialog.message', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.Dialog.state', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_unread_date', full_name='dialog.Dialog.first_unread_date', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='dialog.Dialog.attributes', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pinned_messages', full_name='dialog.Dialog.pinned_messages', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='history_message', full_name='dialog.Dialog.history_message', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14763,
  serialized_end=15386,
)


_REQUESTLOADDIALOGS = _descriptor.Descriptor(
  name='RequestLoadDialogs',
  full_name='dialog.RequestLoadDialogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_date', full_name='dialog.RequestLoadDialogs.min_date', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadDialogs.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLoadDialogs.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='dialog.RequestLoadDialogs.filters', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers_to_load', full_name='dialog.RequestLoadDialogs.peers_to_load', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15389,
  serialized_end=15675,
)


_RESPONSELOADDIALOGS = _descriptor.Descriptor(
  name='ResponseLoadDialogs',
  full_name='dialog.ResponseLoadDialogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadDialogs.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadDialogs.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.ResponseLoadDialogs.dialogs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadDialogs.user_peers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponseLoadDialogs.group_peers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15678,
  serialized_end=15907,
)


_DIALOGINDEX = _descriptor.Descriptor(
  name='DialogIndex',
  full_name='dialog.DialogIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.DialogIndex.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dialog.DialogIndex.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15909,
  serialized_end=15999,
)


_REQUESTFETCHDIALOGINDEX = _descriptor.Descriptor(
  name='RequestFetchDialogIndex',
  full_name='dialog.RequestFetchDialogIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16001,
  serialized_end=16056,
)


_RESPONSEFETCHDIALOGINDEX = _descriptor.Descriptor(
  name='ResponseFetchDialogIndex',
  full_name='dialog.ResponseFetchDialogIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialog_indices', full_name='dialog.ResponseFetchDialogIndex.dialog_indices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16058,
  serialized_end=16160,
)


_REQUESTLOADARCHIVED = _descriptor.Descriptor(
  name='RequestLoadArchived',
  full_name='dialog.RequestLoadArchived',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_offset', full_name='dialog.RequestLoadArchived.next_offset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadArchived.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLoadArchived.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16163,
  serialized_end=16375,
)


_RESPONSELOADARCHIVED = _descriptor.Descriptor(
  name='ResponseLoadArchived',
  full_name='dialog.ResponseLoadArchived',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadArchived.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadArchived.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.ResponseLoadArchived.dialogs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadArchived.user_peers', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponseLoadArchived.group_peers', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_offset', full_name='dialog.ResponseLoadArchived.next_offset', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16378,
  serialized_end=16658,
)


_REQUESTLOADGROUPEDDIALOGS = _descriptor.Descriptor(
  name='RequestLoadGroupedDialogs',
  full_name='dialog.RequestLoadGroupedDialogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLoadGroupedDialogs.optimizations', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16660,
  serialized_end=16768,
)


_RESPONSELOADGROUPEDDIALOGS = _descriptor.Descriptor(
  name='ResponseLoadGroupedDialogs',
  full_name='dialog.ResponseLoadGroupedDialogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.ResponseLoadGroupedDialogs.dialogs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadGroupedDialogs.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadGroupedDialogs.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_archived', full_name='dialog.ResponseLoadGroupedDialogs.show_archived', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_invite', full_name='dialog.ResponseLoadGroupedDialogs.show_invite', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadGroupedDialogs.user_peers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponseLoadGroupedDialogs.group_peers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16771,
  serialized_end=17112,
)


_RESPONSEDIALOGSORDER = _descriptor.Descriptor(
  name='ResponseDialogsOrder',
  full_name='dialog.ResponseDialogsOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseDialogsOrder.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseDialogsOrder.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseDialogsOrder.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17115,
  serialized_end=17278,
)


_REQUESTHIDEDIALOG = _descriptor.Descriptor(
  name='RequestHideDialog',
  full_name='dialog.RequestHideDialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestHideDialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17280,
  serialized_end=17375,
)


_REQUESTSHOWDIALOG = _descriptor.Descriptor(
  name='RequestShowDialog',
  full_name='dialog.RequestShowDialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestShowDialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17377,
  serialized_end=17457,
)


_REQUESTFAVOURITEDIALOG = _descriptor.Descriptor(
  name='RequestFavouriteDialog',
  full_name='dialog.RequestFavouriteDialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestFavouriteDialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17459,
  serialized_end=17559,
)


_REQUESTUNFAVOURITEDIALOG = _descriptor.Descriptor(
  name='RequestUnfavouriteDialog',
  full_name='dialog.RequestUnfavouriteDialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestUnfavouriteDialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17561,
  serialized_end=17663,
)


_UPDATEDIALOGFAVOURITECHANGED = _descriptor.Descriptor(
  name='UpdateDialogFavouriteChanged',
  full_name='dialog.UpdateDialogFavouriteChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateDialogFavouriteChanged.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_favourite', full_name='dialog.UpdateDialogFavouriteChanged.is_favourite', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17666,
  serialized_end=17804,
)


_REQUESTNOTIFYDIALOGOPENED = _descriptor.Descriptor(
  name='RequestNotifyDialogOpened',
  full_name='dialog.RequestNotifyDialogOpened',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestNotifyDialogOpened.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17806,
  serialized_end=17909,
)


_PINNEDMESSAGES = _descriptor.Descriptor(
  name='PinnedMessages',
  full_name='dialog.PinnedMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mids', full_name='dialog.PinnedMessages.mids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17911,
  serialized_end=17975,
)


_REQUESTPINMESSAGE = _descriptor.Descriptor(
  name='RequestPinMessage',
  full_name='dialog.RequestPinMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestPinMessage.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestPinMessage.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_pin_date', full_name='dialog.RequestPinMessage.last_pin_date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17978,
  serialized_end=18158,
)


_REQUESTUNPINMESSAGE = _descriptor.Descriptor(
  name='RequestUnpinMessage',
  full_name='dialog.RequestUnpinMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestUnpinMessage.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.RequestUnpinMessage.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_pin_date', full_name='dialog.RequestUnpinMessage.last_pin_date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18161,
  serialized_end=18343,
)


_UPDATEPINNEDMESSAGESCHANGED = _descriptor.Descriptor(
  name='UpdatePinnedMessagesChanged',
  full_name='dialog.UpdatePinnedMessagesChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdatePinnedMessagesChanged.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pinned_messages', full_name='dialog.UpdatePinnedMessagesChanged.pinned_messages', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_date', full_name='dialog.UpdatePinnedMessagesChanged.action_date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18346,
  serialized_end=18518,
)

_MESSAGEATTRIBUTES.fields_by_name['is_mentioned'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGEATTRIBUTES.fields_by_name['is_highlighted'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGEATTRIBUTES.fields_by_name['is_notified'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGEATTRIBUTES.fields_by_name['is_only_for_you'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_QUOTEDMESSAGE.fields_by_name['quoted_message_content'].message_type = _MESSAGECONTENT
_MESSAGEMEDIA.fields_by_name['webpage'].message_type = _WEBPAGEMEDIA
_MESSAGEMEDIA.fields_by_name['image'].message_type = _IMAGEMEDIA
_MESSAGEMEDIA.fields_by_name['audio'].message_type = _AUDIOMEDIA
_MESSAGEMEDIA.fields_by_name['actions'].message_type = _INTERACTIVEMEDIAGROUP
_WEBPAGEMEDIA.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBPAGEMEDIA.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBPAGEMEDIA.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBPAGEMEDIA.fields_by_name['image'].message_type = media__and__files__pb2._IMAGELOCATION
_IMAGEMEDIA.fields_by_name['image'].message_type = media__and__files__pb2._IMAGELOCATION
_AUDIOMEDIA.fields_by_name['audio'].message_type = media__and__files__pb2._AUDIOLOCATION
_INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaButton'].message_type = _INTERACTIVEMEDIABUTTON
_INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaSelect'].message_type = _INTERACTIVEMEDIASELECT
_INTERACTIVEMEDIAWIDGET.oneofs_by_name['body'].fields.append(
  _INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaButton'])
_INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaButton'].containing_oneof = _INTERACTIVEMEDIAWIDGET.oneofs_by_name['body']
_INTERACTIVEMEDIAWIDGET.oneofs_by_name['body'].fields.append(
  _INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaSelect'])
_INTERACTIVEMEDIAWIDGET.fields_by_name['interactiveMediaSelect'].containing_oneof = _INTERACTIVEMEDIAWIDGET.oneofs_by_name['body']
_INTERACTIVEMEDIABUTTON.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIASELECT.fields_by_name['options'].message_type = _INTERACTIVEMEDIASELECTOPTION
_INTERACTIVEMEDIASELECT.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIASELECT.fields_by_name['default_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIA.fields_by_name['widget'].message_type = _INTERACTIVEMEDIAWIDGET
_INTERACTIVEMEDIA.fields_by_name['style'].enum_type = _INTERACTIVEMEDIASTYLE
_INTERACTIVEMEDIA.fields_by_name['confirm'].message_type = _INTERACTIVEMEDIACONFIRM
_INTERACTIVEMEDIATRANSLATIONGROUP.fields_by_name['messages'].message_type = _INTERACTIVEMEDIATRANSLATION
_INTERACTIVEMEDIAGROUP.fields_by_name['actions'].message_type = _INTERACTIVEMEDIA
_INTERACTIVEMEDIAGROUP.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIAGROUP.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIAGROUP.fields_by_name['translations'].message_type = _INTERACTIVEMEDIATRANSLATIONGROUP
_INTERACTIVEMEDIACONFIRM.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIACONFIRM.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIACONFIRM.fields_by_name['ok'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INTERACTIVEMEDIACONFIRM.fields_by_name['dismiss'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEINTERACTIVEMEDIAEVENT.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTDOINTERACTIVEMEDIAACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_MESSAGECONTENT.fields_by_name['textMessage'].message_type = _TEXTMESSAGE
_MESSAGECONTENT.fields_by_name['serviceMessage'].message_type = _SERVICEMESSAGE
_MESSAGECONTENT.fields_by_name['documentMessage'].message_type = _DOCUMENTMESSAGE
_MESSAGECONTENT.fields_by_name['jsonMessage'].message_type = _JSONMESSAGE
_MESSAGECONTENT.fields_by_name['unsupportedMessage'].message_type = _UNSUPPORTEDMESSAGE
_MESSAGECONTENT.fields_by_name['stickerMessage'].message_type = _STICKERMESSAGE
_MESSAGECONTENT.fields_by_name['binaryMessage'].message_type = _BINARYMESSAGE
_MESSAGECONTENT.fields_by_name['emptyMessage'].message_type = _EMPTYMESSAGE
_MESSAGECONTENT.fields_by_name['deletedMessage'].message_type = _DELETEDMESSAGE
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['textMessage'])
_MESSAGECONTENT.fields_by_name['textMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['serviceMessage'])
_MESSAGECONTENT.fields_by_name['serviceMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['documentMessage'])
_MESSAGECONTENT.fields_by_name['documentMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['jsonMessage'])
_MESSAGECONTENT.fields_by_name['jsonMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['unsupportedMessage'])
_MESSAGECONTENT.fields_by_name['unsupportedMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['stickerMessage'])
_MESSAGECONTENT.fields_by_name['stickerMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['binaryMessage'])
_MESSAGECONTENT.fields_by_name['binaryMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['emptyMessage'])
_MESSAGECONTENT.fields_by_name['emptyMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_MESSAGECONTENT.oneofs_by_name['body'].fields.append(
  _MESSAGECONTENT.fields_by_name['deletedMessage'])
_MESSAGECONTENT.fields_by_name['deletedMessage'].containing_oneof = _MESSAGECONTENT.oneofs_by_name['body']
_TEXTMESSAGE.fields_by_name['ext'].message_type = _TEXTMESSAGEEX
_TEXTMESSAGE.fields_by_name['media'].message_type = _MESSAGEMEDIA
_TEXTMESSAGE.fields_by_name['extensions'].message_type = miscellaneous__pb2._ANY
_TEXTMESSAGEEX.fields_by_name['textExMarkdown'].message_type = _TEXTEXMARKDOWN
_TEXTMESSAGEEX.fields_by_name['textModernMessage'].message_type = _TEXTMODERNMESSAGE
_TEXTMESSAGEEX.fields_by_name['textCommand'].message_type = _TEXTCOMMAND
_TEXTMESSAGEEX.oneofs_by_name['body'].fields.append(
  _TEXTMESSAGEEX.fields_by_name['textExMarkdown'])
_TEXTMESSAGEEX.fields_by_name['textExMarkdown'].containing_oneof = _TEXTMESSAGEEX.oneofs_by_name['body']
_TEXTMESSAGEEX.oneofs_by_name['body'].fields.append(
  _TEXTMESSAGEEX.fields_by_name['textModernMessage'])
_TEXTMESSAGEEX.fields_by_name['textModernMessage'].containing_oneof = _TEXTMESSAGEEX.oneofs_by_name['body']
_TEXTMESSAGEEX.oneofs_by_name['body'].fields.append(
  _TEXTMESSAGEEX.fields_by_name['textCommand'])
_TEXTMESSAGEEX.fields_by_name['textCommand'].containing_oneof = _TEXTMESSAGEEX.oneofs_by_name['body']
_TEXTMODERNMESSAGE.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMODERNMESSAGE.fields_by_name['sender_name_override'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMODERNMESSAGE.fields_by_name['sender_photo_override'].message_type = media__and__files__pb2._AVATAR
_TEXTMODERNMESSAGE.fields_by_name['style'].message_type = _PARAGRAPHSTYLE
_TEXTMODERNMESSAGE.fields_by_name['attaches'].message_type = _TEXTMODERNATTACH
_PARAGRAPHSTYLE.fields_by_name['show_paragraph'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PARAGRAPHSTYLE.fields_by_name['paragraph_color'].message_type = media__and__files__pb2._COLOR
_PARAGRAPHSTYLE.fields_by_name['bg_color'].message_type = media__and__files__pb2._COLOR
_TEXTMODERNATTACH.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMODERNATTACH.fields_by_name['title_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMODERNATTACH.fields_by_name['title_icon'].message_type = media__and__files__pb2._IMAGELOCATION
_TEXTMODERNATTACH.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMODERNATTACH.fields_by_name['style'].message_type = _PARAGRAPHSTYLE
_TEXTMODERNATTACH.fields_by_name['fields'].message_type = _TEXTMODERNFIELD
_TEXTMODERNFIELD.fields_by_name['is_short'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SERVICEMESSAGE.fields_by_name['ext'].message_type = _SERVICEEX
_SERVICEEX.fields_by_name['userInvited'].message_type = _SERVICEEXUSERINVITED
_SERVICEEX.fields_by_name['userJoined'].message_type = _SERVICEEXUSERJOINED
_SERVICEEX.fields_by_name['userKicked'].message_type = _SERVICEEXUSERKICKED
_SERVICEEX.fields_by_name['userLeft'].message_type = _SERVICEEXUSERLEFT
_SERVICEEX.fields_by_name['groupCreated'].message_type = _SERVICEEXGROUPCREATED
_SERVICEEX.fields_by_name['changedTitle'].message_type = _SERVICEEXCHANGEDTITLE
_SERVICEEX.fields_by_name['changedTopic'].message_type = _SERVICEEXCHANGEDTOPIC
_SERVICEEX.fields_by_name['changedAbout'].message_type = _SERVICEEXCHANGEDABOUT
_SERVICEEX.fields_by_name['changedAvatar'].message_type = _SERVICEEXCHANGEDAVATAR
_SERVICEEX.fields_by_name['contactRegistered'].message_type = _SERVICEEXCONTACTREGISTERED
_SERVICEEX.fields_by_name['phoneMissed'].message_type = _SERVICEEXPHONEMISSED
_SERVICEEX.fields_by_name['phoneCall'].message_type = _SERVICEEXPHONECALL
_SERVICEEX.fields_by_name['phoneRejected'].message_type = _SERVICEEXPHONEREJECTED
_SERVICEEX.fields_by_name['chatArchived'].message_type = _SERVICEEXCHATARCHIVED
_SERVICEEX.fields_by_name['chatRestored'].message_type = _SERVICEEXCHATRESTORED
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['userInvited'])
_SERVICEEX.fields_by_name['userInvited'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['userJoined'])
_SERVICEEX.fields_by_name['userJoined'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['userKicked'])
_SERVICEEX.fields_by_name['userKicked'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['userLeft'])
_SERVICEEX.fields_by_name['userLeft'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['groupCreated'])
_SERVICEEX.fields_by_name['groupCreated'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['changedTitle'])
_SERVICEEX.fields_by_name['changedTitle'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['changedTopic'])
_SERVICEEX.fields_by_name['changedTopic'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['changedAbout'])
_SERVICEEX.fields_by_name['changedAbout'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['changedAvatar'])
_SERVICEEX.fields_by_name['changedAvatar'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['contactRegistered'])
_SERVICEEX.fields_by_name['contactRegistered'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['phoneMissed'])
_SERVICEEX.fields_by_name['phoneMissed'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['phoneCall'])
_SERVICEEX.fields_by_name['phoneCall'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['phoneRejected'])
_SERVICEEX.fields_by_name['phoneRejected'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['chatArchived'])
_SERVICEEX.fields_by_name['chatArchived'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEX.oneofs_by_name['body'].fields.append(
  _SERVICEEX.fields_by_name['chatRestored'])
_SERVICEEX.fields_by_name['chatRestored'].containing_oneof = _SERVICEEX.oneofs_by_name['body']
_SERVICEEXCHANGEDTOPIC.fields_by_name['topic'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SERVICEEXCHANGEDABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SERVICEEXCHANGEDAVATAR.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_DOCUMENTMESSAGE.fields_by_name['thumb'].message_type = media__and__files__pb2._FASTTHUMB
_DOCUMENTMESSAGE.fields_by_name['ext'].message_type = _DOCUMENTEX
_DOCUMENTEX.fields_by_name['photo'].message_type = _DOCUMENTEXPHOTO
_DOCUMENTEX.fields_by_name['video'].message_type = _DOCUMENTEXVIDEO
_DOCUMENTEX.fields_by_name['voice'].message_type = _DOCUMENTEXVOICE
_DOCUMENTEX.oneofs_by_name['body'].fields.append(
  _DOCUMENTEX.fields_by_name['photo'])
_DOCUMENTEX.fields_by_name['photo'].containing_oneof = _DOCUMENTEX.oneofs_by_name['body']
_DOCUMENTEX.oneofs_by_name['body'].fields.append(
  _DOCUMENTEX.fields_by_name['video'])
_DOCUMENTEX.fields_by_name['video'].containing_oneof = _DOCUMENTEX.oneofs_by_name['body']
_DOCUMENTEX.oneofs_by_name['body'].fields.append(
  _DOCUMENTEX.fields_by_name['voice'])
_DOCUMENTEX.fields_by_name['voice'].containing_oneof = _DOCUMENTEX.oneofs_by_name['body']
_STICKERMESSAGE.fields_by_name['sticker_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STICKERMESSAGE.fields_by_name['fast_preview'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_STICKERMESSAGE.fields_by_name['image_512'].message_type = media__and__files__pb2._IMAGELOCATION
_STICKERMESSAGE.fields_by_name['image_256'].message_type = media__and__files__pb2._IMAGELOCATION
_STICKERMESSAGE.fields_by_name['sticker_collection_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STICKERMESSAGE.fields_by_name['sticker_collection_access_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_STICKERMESSAGE.fields_by_name['emoji'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DELETEDMESSAGE.fields_by_name['is_local'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DIALOGSHORT.fields_by_name['peer'].message_type = peers__pb2._PEER
_DIALOGGROUP.fields_by_name['dialogs'].message_type = _DIALOGSHORT
_REQUESTSENDMESSAGE.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTSENDMESSAGE.fields_by_name['message'].message_type = _MESSAGECONTENT
_REQUESTSENDMESSAGE.fields_by_name['forward'].message_type = _REFERENCEDMESSAGES
_REQUESTSENDMESSAGE.fields_by_name['reply'].message_type = _REFERENCEDMESSAGES
_REQUESTSENDMESSAGE.fields_by_name['predicates'].message_type = _SEARCHPREDICATE
_REQUESTUPDATEMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTUPDATEMESSAGE.fields_by_name['updated_message'].message_type = _MESSAGECONTENT
_REQUESTMESSAGERECEIVED.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTMESSAGEREAD.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTDELETEMESSAGEOBSOLETE.fields_by_name['mids'].message_type = definitions__pb2._UUIDVALUE
_REQUESTCLEARCHAT.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTDELETECHAT.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTARCHIVECHAT.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTMESSAGESETREACTION.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTMESSAGESETREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTMESSAGEREMOVEREACTION.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTMESSAGEREMOVEREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_RESPONSEREACTIONSRESPONSE.fields_by_name['reactions'].message_type = _MESSAGEREACTION
_RESPONSESENDMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGE.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGE.fields_by_name['message'].message_type = _MESSAGECONTENT
_UPDATEMESSAGE.fields_by_name['attributes'].message_type = _MESSAGEATTRIBUTES
_UPDATEMESSAGE.fields_by_name['forward'].message_type = _REFERENCEDMESSAGES
_UPDATEMESSAGE.fields_by_name['reply'].message_type = _REFERENCEDMESSAGES
_UPDATEMESSAGE.fields_by_name['previous_mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGE.fields_by_name['counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATEMESSAGE.oneofs_by_name['attach'].fields.append(
  _UPDATEMESSAGE.fields_by_name['forward'])
_UPDATEMESSAGE.fields_by_name['forward'].containing_oneof = _UPDATEMESSAGE.oneofs_by_name['attach']
_UPDATEMESSAGE.oneofs_by_name['attach'].fields.append(
  _UPDATEMESSAGE.fields_by_name['reply'])
_UPDATEMESSAGE.fields_by_name['reply'].containing_oneof = _UPDATEMESSAGE.oneofs_by_name['attach']
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['message'].message_type = _MESSAGECONTENT
_UPDATEMESSAGESENT.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGESENT.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGESENT.fields_by_name['prev_mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGESENT.fields_by_name['unread_counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATEMESSAGERECEIVED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEREAD.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEREADBYME.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEREADBYME.fields_by_name['unread_counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATEMESSAGEDELETE.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEDELETE.fields_by_name['mids'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGEDELETE.fields_by_name['counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATECHATCLEAR.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATECHATDELETE.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATECHATARCHIVE.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATECHATGROUPSCHANGED.fields_by_name['dialogs'].message_type = _DIALOGGROUP
_UPDATEREACTIONSUPDATE.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEREACTIONSUPDATE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEREACTIONSUPDATE.fields_by_name['reactions'].message_type = _MESSAGEREACTION
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['reason'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['reason'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REFERENCEDMESSAGES.fields_by_name['mids'].message_type = definitions__pb2._UUIDVALUE
_HISTORYMESSAGE.fields_by_name['sender_peer'].message_type = peers__pb2._OUTPEER
_HISTORYMESSAGE.fields_by_name['host_peer'].message_type = peers__pb2._OUTPEER
_HISTORYMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_HISTORYMESSAGE.fields_by_name['prev_mid'].message_type = definitions__pb2._UUIDVALUE
_HISTORYMESSAGE.fields_by_name['message'].message_type = _MESSAGECONTENT
_HISTORYMESSAGE.fields_by_name['state'].enum_type = _MESSAGESTATE
_HISTORYMESSAGE.fields_by_name['reactions'].message_type = _MESSAGEREACTION
_HISTORYMESSAGE.fields_by_name['attribute'].message_type = _MESSAGEATTRIBUTES
_HISTORYMESSAGE.fields_by_name['forward'].message_type = _REFERENCEDMESSAGES
_HISTORYMESSAGE.fields_by_name['reply'].message_type = _REFERENCEDMESSAGES
_HISTORYMESSAGE.fields_by_name['edited_at'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HISTORYMESSAGE.oneofs_by_name['attach'].fields.append(
  _HISTORYMESSAGE.fields_by_name['forward'])
_HISTORYMESSAGE.fields_by_name['forward'].containing_oneof = _HISTORYMESSAGE.oneofs_by_name['attach']
_HISTORYMESSAGE.oneofs_by_name['attach'].fields.append(
  _HISTORYMESSAGE.fields_by_name['reply'])
_HISTORYMESSAGE.fields_by_name['reply'].containing_oneof = _HISTORYMESSAGE.oneofs_by_name['attach']
_REQUESTLOADHISTORY.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTLOADHISTORY.fields_by_name['load_mode'].enum_type = _LISTLOADMODE
_REQUESTLOADHISTORY.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSELOADHISTORY.fields_by_name['history'].message_type = _HISTORYMESSAGE
_RESPONSELOADHISTORY.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSELOADHISTORY.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADHISTORY.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSELOADHISTORY.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSELOADHISTORY.fields_by_name['counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_DIALOG.fields_by_name['peer'].message_type = peers__pb2._PEER
_DIALOG.fields_by_name['is_favourite'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DIALOG.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_DIALOG.fields_by_name['message'].message_type = _MESSAGECONTENT
_DIALOG.fields_by_name['state'].enum_type = _MESSAGESTATE
_DIALOG.fields_by_name['attributes'].message_type = _MESSAGEATTRIBUTES
_DIALOG.fields_by_name['pinned_messages'].message_type = _PINNEDMESSAGES
_DIALOG.fields_by_name['history_message'].message_type = _HISTORYMESSAGE
_REQUESTLOADDIALOGS.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTLOADDIALOGS.fields_by_name['filters'].enum_type = _DIALOGSFILTER
_REQUESTLOADDIALOGS.fields_by_name['peers_to_load'].message_type = peers__pb2._PEER
_RESPONSELOADDIALOGS.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSELOADDIALOGS.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSELOADDIALOGS.fields_by_name['dialogs'].message_type = _DIALOG
_RESPONSELOADDIALOGS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADDIALOGS.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_DIALOGINDEX.fields_by_name['peer'].message_type = peers__pb2._PEER
_RESPONSEFETCHDIALOGINDEX.fields_by_name['dialog_indices'].message_type = _DIALOGINDEX
_REQUESTLOADARCHIVED.fields_by_name['next_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_REQUESTLOADARCHIVED.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSELOADARCHIVED.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSELOADARCHIVED.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSELOADARCHIVED.fields_by_name['dialogs'].message_type = _DIALOG
_RESPONSELOADARCHIVED.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADARCHIVED.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSELOADARCHIVED.fields_by_name['next_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_REQUESTLOADGROUPEDDIALOGS.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['dialogs'].message_type = _DIALOGGROUP
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['show_archived'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['show_invite'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADGROUPEDDIALOGS.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSEDIALOGSORDER.fields_by_name['groups'].message_type = _DIALOGGROUP
_REQUESTHIDEDIALOG.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTSHOWDIALOG.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTFAVOURITEDIALOG.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTUNFAVOURITEDIALOG.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_UPDATEDIALOGFAVOURITECHANGED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEDIALOGFAVOURITECHANGED.fields_by_name['is_favourite'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REQUESTNOTIFYDIALOGOPENED.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_PINNEDMESSAGES.fields_by_name['mids'].message_type = definitions__pb2._UUIDVALUE
_REQUESTPINMESSAGE.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTPINMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTUNPINMESSAGE.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTUNPINMESSAGE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEPINNEDMESSAGESCHANGED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEPINNEDMESSAGESCHANGED.fields_by_name['pinned_messages'].message_type = _PINNEDMESSAGES
DESCRIPTOR.message_types_by_name['MessageAttributes'] = _MESSAGEATTRIBUTES
DESCRIPTOR.message_types_by_name['QuotedMessage'] = _QUOTEDMESSAGE
DESCRIPTOR.message_types_by_name['MessageMedia'] = _MESSAGEMEDIA
DESCRIPTOR.message_types_by_name['WebpageMedia'] = _WEBPAGEMEDIA
DESCRIPTOR.message_types_by_name['ImageMedia'] = _IMAGEMEDIA
DESCRIPTOR.message_types_by_name['AudioMedia'] = _AUDIOMEDIA
DESCRIPTOR.message_types_by_name['InteractiveMediaWidget'] = _INTERACTIVEMEDIAWIDGET
DESCRIPTOR.message_types_by_name['InteractiveMediaButton'] = _INTERACTIVEMEDIABUTTON
DESCRIPTOR.message_types_by_name['InteractiveMediaSelect'] = _INTERACTIVEMEDIASELECT
DESCRIPTOR.message_types_by_name['InteractiveMediaSelectOption'] = _INTERACTIVEMEDIASELECTOPTION
DESCRIPTOR.message_types_by_name['InteractiveMedia'] = _INTERACTIVEMEDIA
DESCRIPTOR.message_types_by_name['InteractiveMediaTranslation'] = _INTERACTIVEMEDIATRANSLATION
DESCRIPTOR.message_types_by_name['InteractiveMediaTranslationGroup'] = _INTERACTIVEMEDIATRANSLATIONGROUP
DESCRIPTOR.message_types_by_name['InteractiveMediaGroup'] = _INTERACTIVEMEDIAGROUP
DESCRIPTOR.message_types_by_name['InteractiveMediaConfirm'] = _INTERACTIVEMEDIACONFIRM
DESCRIPTOR.message_types_by_name['UpdateInteractiveMediaEvent'] = _UPDATEINTERACTIVEMEDIAEVENT
DESCRIPTOR.message_types_by_name['RequestDoInteractiveMediaAction'] = _REQUESTDOINTERACTIVEMEDIAACTION
DESCRIPTOR.message_types_by_name['MessageContent'] = _MESSAGECONTENT
DESCRIPTOR.message_types_by_name['TextMessage'] = _TEXTMESSAGE
DESCRIPTOR.message_types_by_name['TextMessageEx'] = _TEXTMESSAGEEX
DESCRIPTOR.message_types_by_name['TextExMarkdown'] = _TEXTEXMARKDOWN
DESCRIPTOR.message_types_by_name['TextModernMessage'] = _TEXTMODERNMESSAGE
DESCRIPTOR.message_types_by_name['ParagraphStyle'] = _PARAGRAPHSTYLE
DESCRIPTOR.message_types_by_name['TextModernAttach'] = _TEXTMODERNATTACH
DESCRIPTOR.message_types_by_name['TextModernField'] = _TEXTMODERNFIELD
DESCRIPTOR.message_types_by_name['TextCommand'] = _TEXTCOMMAND
DESCRIPTOR.message_types_by_name['ServiceMessage'] = _SERVICEMESSAGE
DESCRIPTOR.message_types_by_name['ServiceEx'] = _SERVICEEX
DESCRIPTOR.message_types_by_name['ServiceExUserInvited'] = _SERVICEEXUSERINVITED
DESCRIPTOR.message_types_by_name['ServiceExUserJoined'] = _SERVICEEXUSERJOINED
DESCRIPTOR.message_types_by_name['ServiceExUserKicked'] = _SERVICEEXUSERKICKED
DESCRIPTOR.message_types_by_name['ServiceExUserLeft'] = _SERVICEEXUSERLEFT
DESCRIPTOR.message_types_by_name['ServiceExGroupCreated'] = _SERVICEEXGROUPCREATED
DESCRIPTOR.message_types_by_name['ServiceExChangedTitle'] = _SERVICEEXCHANGEDTITLE
DESCRIPTOR.message_types_by_name['ServiceExChangedTopic'] = _SERVICEEXCHANGEDTOPIC
DESCRIPTOR.message_types_by_name['ServiceExChangedAbout'] = _SERVICEEXCHANGEDABOUT
DESCRIPTOR.message_types_by_name['ServiceExChangedAvatar'] = _SERVICEEXCHANGEDAVATAR
DESCRIPTOR.message_types_by_name['ServiceExContactRegistered'] = _SERVICEEXCONTACTREGISTERED
DESCRIPTOR.message_types_by_name['ServiceExPhoneMissed'] = _SERVICEEXPHONEMISSED
DESCRIPTOR.message_types_by_name['ServiceExPhoneCall'] = _SERVICEEXPHONECALL
DESCRIPTOR.message_types_by_name['ServiceExPhoneRejected'] = _SERVICEEXPHONEREJECTED
DESCRIPTOR.message_types_by_name['ServiceExChatArchived'] = _SERVICEEXCHATARCHIVED
DESCRIPTOR.message_types_by_name['ServiceExChatRestored'] = _SERVICEEXCHATRESTORED
DESCRIPTOR.message_types_by_name['DocumentMessage'] = _DOCUMENTMESSAGE
DESCRIPTOR.message_types_by_name['DocumentEx'] = _DOCUMENTEX
DESCRIPTOR.message_types_by_name['DocumentExPhoto'] = _DOCUMENTEXPHOTO
DESCRIPTOR.message_types_by_name['DocumentExVideo'] = _DOCUMENTEXVIDEO
DESCRIPTOR.message_types_by_name['DocumentExVoice'] = _DOCUMENTEXVOICE
DESCRIPTOR.message_types_by_name['JsonMessage'] = _JSONMESSAGE
DESCRIPTOR.message_types_by_name['UnsupportedMessage'] = _UNSUPPORTEDMESSAGE
DESCRIPTOR.message_types_by_name['StickerMessage'] = _STICKERMESSAGE
DESCRIPTOR.message_types_by_name['BinaryMessage'] = _BINARYMESSAGE
DESCRIPTOR.message_types_by_name['EmptyMessage'] = _EMPTYMESSAGE
DESCRIPTOR.message_types_by_name['DeletedMessage'] = _DELETEDMESSAGE
DESCRIPTOR.message_types_by_name['DialogShort'] = _DIALOGSHORT
DESCRIPTOR.message_types_by_name['DialogGroup'] = _DIALOGGROUP
DESCRIPTOR.message_types_by_name['MessageReaction'] = _MESSAGEREACTION
DESCRIPTOR.message_types_by_name['SearchPredicate'] = _SEARCHPREDICATE
DESCRIPTOR.message_types_by_name['RequestSendMessage'] = _REQUESTSENDMESSAGE
DESCRIPTOR.message_types_by_name['RequestUpdateMessage'] = _REQUESTUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['RequestMessageReceived'] = _REQUESTMESSAGERECEIVED
DESCRIPTOR.message_types_by_name['RequestMessageRead'] = _REQUESTMESSAGEREAD
DESCRIPTOR.message_types_by_name['RequestDeleteMessageObsolete'] = _REQUESTDELETEMESSAGEOBSOLETE
DESCRIPTOR.message_types_by_name['RequestClearChat'] = _REQUESTCLEARCHAT
DESCRIPTOR.message_types_by_name['RequestDeleteChat'] = _REQUESTDELETECHAT
DESCRIPTOR.message_types_by_name['RequestArchiveChat'] = _REQUESTARCHIVECHAT
DESCRIPTOR.message_types_by_name['RequestMessageSetReaction'] = _REQUESTMESSAGESETREACTION
DESCRIPTOR.message_types_by_name['RequestMessageRemoveReaction'] = _REQUESTMESSAGEREMOVEREACTION
DESCRIPTOR.message_types_by_name['ResponseReactionsResponse'] = _RESPONSEREACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['ResponseSendMessage'] = _RESPONSESENDMESSAGE
DESCRIPTOR.message_types_by_name['UpdateMessage'] = _UPDATEMESSAGE
DESCRIPTOR.message_types_by_name['UpdateMessageContentChanged'] = _UPDATEMESSAGECONTENTCHANGED
DESCRIPTOR.message_types_by_name['UpdateMessageSent'] = _UPDATEMESSAGESENT
DESCRIPTOR.message_types_by_name['UpdateMessageReceived'] = _UPDATEMESSAGERECEIVED
DESCRIPTOR.message_types_by_name['UpdateMessageRead'] = _UPDATEMESSAGEREAD
DESCRIPTOR.message_types_by_name['UpdateMessageReadByMe'] = _UPDATEMESSAGEREADBYME
DESCRIPTOR.message_types_by_name['UpdateMessageDelete'] = _UPDATEMESSAGEDELETE
DESCRIPTOR.message_types_by_name['UpdateChatClear'] = _UPDATECHATCLEAR
DESCRIPTOR.message_types_by_name['UpdateChatDelete'] = _UPDATECHATDELETE
DESCRIPTOR.message_types_by_name['UpdateChatArchive'] = _UPDATECHATARCHIVE
DESCRIPTOR.message_types_by_name['UpdateChatGroupsChanged'] = _UPDATECHATGROUPSCHANGED
DESCRIPTOR.message_types_by_name['UpdateReactionsUpdate'] = _UPDATEREACTIONSUPDATE
DESCRIPTOR.message_types_by_name['UpdateMessageRejectedByHook'] = _UPDATEMESSAGEREJECTEDBYHOOK
DESCRIPTOR.message_types_by_name['UpdateMessageEditRejectedByHook'] = _UPDATEMESSAGEEDITREJECTEDBYHOOK
DESCRIPTOR.message_types_by_name['ReferencedMessages'] = _REFERENCEDMESSAGES
DESCRIPTOR.message_types_by_name['HistoryMessage'] = _HISTORYMESSAGE
DESCRIPTOR.message_types_by_name['RequestLoadHistory'] = _REQUESTLOADHISTORY
DESCRIPTOR.message_types_by_name['ResponseLoadHistory'] = _RESPONSELOADHISTORY
DESCRIPTOR.message_types_by_name['Dialog'] = _DIALOG
DESCRIPTOR.message_types_by_name['RequestLoadDialogs'] = _REQUESTLOADDIALOGS
DESCRIPTOR.message_types_by_name['ResponseLoadDialogs'] = _RESPONSELOADDIALOGS
DESCRIPTOR.message_types_by_name['DialogIndex'] = _DIALOGINDEX
DESCRIPTOR.message_types_by_name['RequestFetchDialogIndex'] = _REQUESTFETCHDIALOGINDEX
DESCRIPTOR.message_types_by_name['ResponseFetchDialogIndex'] = _RESPONSEFETCHDIALOGINDEX
DESCRIPTOR.message_types_by_name['RequestLoadArchived'] = _REQUESTLOADARCHIVED
DESCRIPTOR.message_types_by_name['ResponseLoadArchived'] = _RESPONSELOADARCHIVED
DESCRIPTOR.message_types_by_name['RequestLoadGroupedDialogs'] = _REQUESTLOADGROUPEDDIALOGS
DESCRIPTOR.message_types_by_name['ResponseLoadGroupedDialogs'] = _RESPONSELOADGROUPEDDIALOGS
DESCRIPTOR.message_types_by_name['ResponseDialogsOrder'] = _RESPONSEDIALOGSORDER
DESCRIPTOR.message_types_by_name['RequestHideDialog'] = _REQUESTHIDEDIALOG
DESCRIPTOR.message_types_by_name['RequestShowDialog'] = _REQUESTSHOWDIALOG
DESCRIPTOR.message_types_by_name['RequestFavouriteDialog'] = _REQUESTFAVOURITEDIALOG
DESCRIPTOR.message_types_by_name['RequestUnfavouriteDialog'] = _REQUESTUNFAVOURITEDIALOG
DESCRIPTOR.message_types_by_name['UpdateDialogFavouriteChanged'] = _UPDATEDIALOGFAVOURITECHANGED
DESCRIPTOR.message_types_by_name['RequestNotifyDialogOpened'] = _REQUESTNOTIFYDIALOGOPENED
DESCRIPTOR.message_types_by_name['PinnedMessages'] = _PINNEDMESSAGES
DESCRIPTOR.message_types_by_name['RequestPinMessage'] = _REQUESTPINMESSAGE
DESCRIPTOR.message_types_by_name['RequestUnpinMessage'] = _REQUESTUNPINMESSAGE
DESCRIPTOR.message_types_by_name['UpdatePinnedMessagesChanged'] = _UPDATEPINNEDMESSAGESCHANGED
DESCRIPTOR.enum_types_by_name['InteractiveMediaStyle'] = _INTERACTIVEMEDIASTYLE
DESCRIPTOR.enum_types_by_name['MessageState'] = _MESSAGESTATE
DESCRIPTOR.enum_types_by_name['ListLoadMode'] = _LISTLOADMODE
DESCRIPTOR.enum_types_by_name['DialogsFilter'] = _DIALOGSFILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageAttributes = _reflection.GeneratedProtocolMessageType('MessageAttributes', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGEATTRIBUTES,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageAttributes)
  ))
_sym_db.RegisterMessage(MessageAttributes)

QuotedMessage = _reflection.GeneratedProtocolMessageType('QuotedMessage', (_message.Message,), dict(
  DESCRIPTOR = _QUOTEDMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.QuotedMessage)
  ))
_sym_db.RegisterMessage(QuotedMessage)

MessageMedia = _reflection.GeneratedProtocolMessageType('MessageMedia', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGEMEDIA,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageMedia)
  ))
_sym_db.RegisterMessage(MessageMedia)

WebpageMedia = _reflection.GeneratedProtocolMessageType('WebpageMedia', (_message.Message,), dict(
  DESCRIPTOR = _WEBPAGEMEDIA,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.WebpageMedia)
  ))
_sym_db.RegisterMessage(WebpageMedia)

ImageMedia = _reflection.GeneratedProtocolMessageType('ImageMedia', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEMEDIA,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ImageMedia)
  ))
_sym_db.RegisterMessage(ImageMedia)

AudioMedia = _reflection.GeneratedProtocolMessageType('AudioMedia', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOMEDIA,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AudioMedia)
  ))
_sym_db.RegisterMessage(AudioMedia)

InteractiveMediaWidget = _reflection.GeneratedProtocolMessageType('InteractiveMediaWidget', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIAWIDGET,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaWidget)
  ))
_sym_db.RegisterMessage(InteractiveMediaWidget)

InteractiveMediaButton = _reflection.GeneratedProtocolMessageType('InteractiveMediaButton', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIABUTTON,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaButton)
  ))
_sym_db.RegisterMessage(InteractiveMediaButton)

InteractiveMediaSelect = _reflection.GeneratedProtocolMessageType('InteractiveMediaSelect', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIASELECT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaSelect)
  ))
_sym_db.RegisterMessage(InteractiveMediaSelect)

InteractiveMediaSelectOption = _reflection.GeneratedProtocolMessageType('InteractiveMediaSelectOption', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIASELECTOPTION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaSelectOption)
  ))
_sym_db.RegisterMessage(InteractiveMediaSelectOption)

InteractiveMedia = _reflection.GeneratedProtocolMessageType('InteractiveMedia', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIA,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMedia)
  ))
_sym_db.RegisterMessage(InteractiveMedia)

InteractiveMediaTranslation = _reflection.GeneratedProtocolMessageType('InteractiveMediaTranslation', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIATRANSLATION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaTranslation)
  ))
_sym_db.RegisterMessage(InteractiveMediaTranslation)

InteractiveMediaTranslationGroup = _reflection.GeneratedProtocolMessageType('InteractiveMediaTranslationGroup', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIATRANSLATIONGROUP,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaTranslationGroup)
  ))
_sym_db.RegisterMessage(InteractiveMediaTranslationGroup)

InteractiveMediaGroup = _reflection.GeneratedProtocolMessageType('InteractiveMediaGroup', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIAGROUP,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaGroup)
  ))
_sym_db.RegisterMessage(InteractiveMediaGroup)

InteractiveMediaConfirm = _reflection.GeneratedProtocolMessageType('InteractiveMediaConfirm', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIVEMEDIACONFIRM,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InteractiveMediaConfirm)
  ))
_sym_db.RegisterMessage(InteractiveMediaConfirm)

UpdateInteractiveMediaEvent = _reflection.GeneratedProtocolMessageType('UpdateInteractiveMediaEvent', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEINTERACTIVEMEDIAEVENT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateInteractiveMediaEvent)
  ))
_sym_db.RegisterMessage(UpdateInteractiveMediaEvent)

RequestDoInteractiveMediaAction = _reflection.GeneratedProtocolMessageType('RequestDoInteractiveMediaAction', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTDOINTERACTIVEMEDIAACTION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDoInteractiveMediaAction)
  ))
_sym_db.RegisterMessage(RequestDoInteractiveMediaAction)

MessageContent = _reflection.GeneratedProtocolMessageType('MessageContent', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGECONTENT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageContent)
  ))
_sym_db.RegisterMessage(MessageContent)

TextMessage = _reflection.GeneratedProtocolMessageType('TextMessage', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextMessage)
  ))
_sym_db.RegisterMessage(TextMessage)

TextMessageEx = _reflection.GeneratedProtocolMessageType('TextMessageEx', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMESSAGEEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextMessageEx)
  ))
_sym_db.RegisterMessage(TextMessageEx)

TextExMarkdown = _reflection.GeneratedProtocolMessageType('TextExMarkdown', (_message.Message,), dict(
  DESCRIPTOR = _TEXTEXMARKDOWN,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextExMarkdown)
  ))
_sym_db.RegisterMessage(TextExMarkdown)

TextModernMessage = _reflection.GeneratedProtocolMessageType('TextModernMessage', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMODERNMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextModernMessage)
  ))
_sym_db.RegisterMessage(TextModernMessage)

ParagraphStyle = _reflection.GeneratedProtocolMessageType('ParagraphStyle', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ParagraphStyle)
  ))
_sym_db.RegisterMessage(ParagraphStyle)

TextModernAttach = _reflection.GeneratedProtocolMessageType('TextModernAttach', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMODERNATTACH,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextModernAttach)
  ))
_sym_db.RegisterMessage(TextModernAttach)

TextModernField = _reflection.GeneratedProtocolMessageType('TextModernField', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMODERNFIELD,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextModernField)
  ))
_sym_db.RegisterMessage(TextModernField)

TextCommand = _reflection.GeneratedProtocolMessageType('TextCommand', (_message.Message,), dict(
  DESCRIPTOR = _TEXTCOMMAND,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.TextCommand)
  ))
_sym_db.RegisterMessage(TextCommand)

ServiceMessage = _reflection.GeneratedProtocolMessageType('ServiceMessage', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceMessage)
  ))
_sym_db.RegisterMessage(ServiceMessage)

ServiceEx = _reflection.GeneratedProtocolMessageType('ServiceEx', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceEx)
  ))
_sym_db.RegisterMessage(ServiceEx)

ServiceExUserInvited = _reflection.GeneratedProtocolMessageType('ServiceExUserInvited', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXUSERINVITED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExUserInvited)
  ))
_sym_db.RegisterMessage(ServiceExUserInvited)

ServiceExUserJoined = _reflection.GeneratedProtocolMessageType('ServiceExUserJoined', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXUSERJOINED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExUserJoined)
  ))
_sym_db.RegisterMessage(ServiceExUserJoined)

ServiceExUserKicked = _reflection.GeneratedProtocolMessageType('ServiceExUserKicked', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXUSERKICKED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExUserKicked)
  ))
_sym_db.RegisterMessage(ServiceExUserKicked)

ServiceExUserLeft = _reflection.GeneratedProtocolMessageType('ServiceExUserLeft', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXUSERLEFT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExUserLeft)
  ))
_sym_db.RegisterMessage(ServiceExUserLeft)

ServiceExGroupCreated = _reflection.GeneratedProtocolMessageType('ServiceExGroupCreated', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXGROUPCREATED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExGroupCreated)
  ))
_sym_db.RegisterMessage(ServiceExGroupCreated)

ServiceExChangedTitle = _reflection.GeneratedProtocolMessageType('ServiceExChangedTitle', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHANGEDTITLE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChangedTitle)
  ))
_sym_db.RegisterMessage(ServiceExChangedTitle)

ServiceExChangedTopic = _reflection.GeneratedProtocolMessageType('ServiceExChangedTopic', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHANGEDTOPIC,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChangedTopic)
  ))
_sym_db.RegisterMessage(ServiceExChangedTopic)

ServiceExChangedAbout = _reflection.GeneratedProtocolMessageType('ServiceExChangedAbout', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHANGEDABOUT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChangedAbout)
  ))
_sym_db.RegisterMessage(ServiceExChangedAbout)

ServiceExChangedAvatar = _reflection.GeneratedProtocolMessageType('ServiceExChangedAvatar', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHANGEDAVATAR,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChangedAvatar)
  ))
_sym_db.RegisterMessage(ServiceExChangedAvatar)

ServiceExContactRegistered = _reflection.GeneratedProtocolMessageType('ServiceExContactRegistered', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCONTACTREGISTERED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExContactRegistered)
  ))
_sym_db.RegisterMessage(ServiceExContactRegistered)

ServiceExPhoneMissed = _reflection.GeneratedProtocolMessageType('ServiceExPhoneMissed', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXPHONEMISSED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExPhoneMissed)
  ))
_sym_db.RegisterMessage(ServiceExPhoneMissed)

ServiceExPhoneCall = _reflection.GeneratedProtocolMessageType('ServiceExPhoneCall', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXPHONECALL,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExPhoneCall)
  ))
_sym_db.RegisterMessage(ServiceExPhoneCall)

ServiceExPhoneRejected = _reflection.GeneratedProtocolMessageType('ServiceExPhoneRejected', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXPHONEREJECTED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExPhoneRejected)
  ))
_sym_db.RegisterMessage(ServiceExPhoneRejected)

ServiceExChatArchived = _reflection.GeneratedProtocolMessageType('ServiceExChatArchived', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHATARCHIVED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChatArchived)
  ))
_sym_db.RegisterMessage(ServiceExChatArchived)

ServiceExChatRestored = _reflection.GeneratedProtocolMessageType('ServiceExChatRestored', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEEXCHATRESTORED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceExChatRestored)
  ))
_sym_db.RegisterMessage(ServiceExChatRestored)

DocumentMessage = _reflection.GeneratedProtocolMessageType('DocumentMessage', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DocumentMessage)
  ))
_sym_db.RegisterMessage(DocumentMessage)

DocumentEx = _reflection.GeneratedProtocolMessageType('DocumentEx', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DocumentEx)
  ))
_sym_db.RegisterMessage(DocumentEx)

DocumentExPhoto = _reflection.GeneratedProtocolMessageType('DocumentExPhoto', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTEXPHOTO,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DocumentExPhoto)
  ))
_sym_db.RegisterMessage(DocumentExPhoto)

DocumentExVideo = _reflection.GeneratedProtocolMessageType('DocumentExVideo', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTEXVIDEO,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DocumentExVideo)
  ))
_sym_db.RegisterMessage(DocumentExVideo)

DocumentExVoice = _reflection.GeneratedProtocolMessageType('DocumentExVoice', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTEXVOICE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DocumentExVoice)
  ))
_sym_db.RegisterMessage(DocumentExVoice)

JsonMessage = _reflection.GeneratedProtocolMessageType('JsonMessage', (_message.Message,), dict(
  DESCRIPTOR = _JSONMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.JsonMessage)
  ))
_sym_db.RegisterMessage(JsonMessage)

UnsupportedMessage = _reflection.GeneratedProtocolMessageType('UnsupportedMessage', (_message.Message,), dict(
  DESCRIPTOR = _UNSUPPORTEDMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UnsupportedMessage)
  ))
_sym_db.RegisterMessage(UnsupportedMessage)

StickerMessage = _reflection.GeneratedProtocolMessageType('StickerMessage', (_message.Message,), dict(
  DESCRIPTOR = _STICKERMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.StickerMessage)
  ))
_sym_db.RegisterMessage(StickerMessage)

BinaryMessage = _reflection.GeneratedProtocolMessageType('BinaryMessage', (_message.Message,), dict(
  DESCRIPTOR = _BINARYMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.BinaryMessage)
  ))
_sym_db.RegisterMessage(BinaryMessage)

EmptyMessage = _reflection.GeneratedProtocolMessageType('EmptyMessage', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.EmptyMessage)
  ))
_sym_db.RegisterMessage(EmptyMessage)

DeletedMessage = _reflection.GeneratedProtocolMessageType('DeletedMessage', (_message.Message,), dict(
  DESCRIPTOR = _DELETEDMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DeletedMessage)
  ))
_sym_db.RegisterMessage(DeletedMessage)

DialogShort = _reflection.GeneratedProtocolMessageType('DialogShort', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGSHORT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DialogShort)
  ))
_sym_db.RegisterMessage(DialogShort)

DialogGroup = _reflection.GeneratedProtocolMessageType('DialogGroup', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGGROUP,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DialogGroup)
  ))
_sym_db.RegisterMessage(DialogGroup)

MessageReaction = _reflection.GeneratedProtocolMessageType('MessageReaction', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGEREACTION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageReaction)
  ))
_sym_db.RegisterMessage(MessageReaction)

SearchPredicate = _reflection.GeneratedProtocolMessageType('SearchPredicate', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPREDICATE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchPredicate)
  ))
_sym_db.RegisterMessage(SearchPredicate)

RequestSendMessage = _reflection.GeneratedProtocolMessageType('RequestSendMessage', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSENDMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSendMessage)
  ))
_sym_db.RegisterMessage(RequestSendMessage)

RequestUpdateMessage = _reflection.GeneratedProtocolMessageType('RequestUpdateMessage', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTUPDATEMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUpdateMessage)
  ))
_sym_db.RegisterMessage(RequestUpdateMessage)

RequestMessageReceived = _reflection.GeneratedProtocolMessageType('RequestMessageReceived', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGERECEIVED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageReceived)
  ))
_sym_db.RegisterMessage(RequestMessageReceived)

RequestMessageRead = _reflection.GeneratedProtocolMessageType('RequestMessageRead', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGEREAD,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageRead)
  ))
_sym_db.RegisterMessage(RequestMessageRead)

RequestDeleteMessageObsolete = _reflection.GeneratedProtocolMessageType('RequestDeleteMessageObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTDELETEMESSAGEOBSOLETE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteMessageObsolete)
  ))
_sym_db.RegisterMessage(RequestDeleteMessageObsolete)

RequestClearChat = _reflection.GeneratedProtocolMessageType('RequestClearChat', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCLEARCHAT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestClearChat)
  ))
_sym_db.RegisterMessage(RequestClearChat)

RequestDeleteChat = _reflection.GeneratedProtocolMessageType('RequestDeleteChat', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTDELETECHAT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteChat)
  ))
_sym_db.RegisterMessage(RequestDeleteChat)

RequestArchiveChat = _reflection.GeneratedProtocolMessageType('RequestArchiveChat', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTARCHIVECHAT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestArchiveChat)
  ))
_sym_db.RegisterMessage(RequestArchiveChat)

RequestMessageSetReaction = _reflection.GeneratedProtocolMessageType('RequestMessageSetReaction', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGESETREACTION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageSetReaction)
  ))
_sym_db.RegisterMessage(RequestMessageSetReaction)

RequestMessageRemoveReaction = _reflection.GeneratedProtocolMessageType('RequestMessageRemoveReaction', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGEREMOVEREACTION,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageRemoveReaction)
  ))
_sym_db.RegisterMessage(RequestMessageRemoveReaction)

ResponseReactionsResponse = _reflection.GeneratedProtocolMessageType('ResponseReactionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEREACTIONSRESPONSE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseReactionsResponse)
  ))
_sym_db.RegisterMessage(ResponseReactionsResponse)

ResponseSendMessage = _reflection.GeneratedProtocolMessageType('ResponseSendMessage', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESENDMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSendMessage)
  ))
_sym_db.RegisterMessage(ResponseSendMessage)

UpdateMessage = _reflection.GeneratedProtocolMessageType('UpdateMessage', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessage)
  ))
_sym_db.RegisterMessage(UpdateMessage)

UpdateMessageContentChanged = _reflection.GeneratedProtocolMessageType('UpdateMessageContentChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGECONTENTCHANGED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageContentChanged)
  ))
_sym_db.RegisterMessage(UpdateMessageContentChanged)

UpdateMessageSent = _reflection.GeneratedProtocolMessageType('UpdateMessageSent', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGESENT,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageSent)
  ))
_sym_db.RegisterMessage(UpdateMessageSent)

UpdateMessageReceived = _reflection.GeneratedProtocolMessageType('UpdateMessageReceived', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGERECEIVED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageReceived)
  ))
_sym_db.RegisterMessage(UpdateMessageReceived)

UpdateMessageRead = _reflection.GeneratedProtocolMessageType('UpdateMessageRead', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGEREAD,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageRead)
  ))
_sym_db.RegisterMessage(UpdateMessageRead)

UpdateMessageReadByMe = _reflection.GeneratedProtocolMessageType('UpdateMessageReadByMe', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGEREADBYME,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageReadByMe)
  ))
_sym_db.RegisterMessage(UpdateMessageReadByMe)

UpdateMessageDelete = _reflection.GeneratedProtocolMessageType('UpdateMessageDelete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGEDELETE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageDelete)
  ))
_sym_db.RegisterMessage(UpdateMessageDelete)

UpdateChatClear = _reflection.GeneratedProtocolMessageType('UpdateChatClear', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECHATCLEAR,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateChatClear)
  ))
_sym_db.RegisterMessage(UpdateChatClear)

UpdateChatDelete = _reflection.GeneratedProtocolMessageType('UpdateChatDelete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECHATDELETE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateChatDelete)
  ))
_sym_db.RegisterMessage(UpdateChatDelete)

UpdateChatArchive = _reflection.GeneratedProtocolMessageType('UpdateChatArchive', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECHATARCHIVE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateChatArchive)
  ))
_sym_db.RegisterMessage(UpdateChatArchive)

UpdateChatGroupsChanged = _reflection.GeneratedProtocolMessageType('UpdateChatGroupsChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECHATGROUPSCHANGED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateChatGroupsChanged)
  ))
_sym_db.RegisterMessage(UpdateChatGroupsChanged)

UpdateReactionsUpdate = _reflection.GeneratedProtocolMessageType('UpdateReactionsUpdate', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEREACTIONSUPDATE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateReactionsUpdate)
  ))
_sym_db.RegisterMessage(UpdateReactionsUpdate)

UpdateMessageRejectedByHook = _reflection.GeneratedProtocolMessageType('UpdateMessageRejectedByHook', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGEREJECTEDBYHOOK,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageRejectedByHook)
  ))
_sym_db.RegisterMessage(UpdateMessageRejectedByHook)

UpdateMessageEditRejectedByHook = _reflection.GeneratedProtocolMessageType('UpdateMessageEditRejectedByHook', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEMESSAGEEDITREJECTEDBYHOOK,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMessageEditRejectedByHook)
  ))
_sym_db.RegisterMessage(UpdateMessageEditRejectedByHook)

ReferencedMessages = _reflection.GeneratedProtocolMessageType('ReferencedMessages', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCEDMESSAGES,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ReferencedMessages)
  ))
_sym_db.RegisterMessage(ReferencedMessages)

HistoryMessage = _reflection.GeneratedProtocolMessageType('HistoryMessage', (_message.Message,), dict(
  DESCRIPTOR = _HISTORYMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.HistoryMessage)
  ))
_sym_db.RegisterMessage(HistoryMessage)

RequestLoadHistory = _reflection.GeneratedProtocolMessageType('RequestLoadHistory', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADHISTORY,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadHistory)
  ))
_sym_db.RegisterMessage(RequestLoadHistory)

ResponseLoadHistory = _reflection.GeneratedProtocolMessageType('ResponseLoadHistory', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADHISTORY,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadHistory)
  ))
_sym_db.RegisterMessage(ResponseLoadHistory)

Dialog = _reflection.GeneratedProtocolMessageType('Dialog', (_message.Message,), dict(
  DESCRIPTOR = _DIALOG,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Dialog)
  ))
_sym_db.RegisterMessage(Dialog)

RequestLoadDialogs = _reflection.GeneratedProtocolMessageType('RequestLoadDialogs', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADDIALOGS,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadDialogs)
  ))
_sym_db.RegisterMessage(RequestLoadDialogs)

ResponseLoadDialogs = _reflection.GeneratedProtocolMessageType('ResponseLoadDialogs', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADDIALOGS,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadDialogs)
  ))
_sym_db.RegisterMessage(ResponseLoadDialogs)

DialogIndex = _reflection.GeneratedProtocolMessageType('DialogIndex', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGINDEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DialogIndex)
  ))
_sym_db.RegisterMessage(DialogIndex)

RequestFetchDialogIndex = _reflection.GeneratedProtocolMessageType('RequestFetchDialogIndex', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTFETCHDIALOGINDEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestFetchDialogIndex)
  ))
_sym_db.RegisterMessage(RequestFetchDialogIndex)

ResponseFetchDialogIndex = _reflection.GeneratedProtocolMessageType('ResponseFetchDialogIndex', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEFETCHDIALOGINDEX,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseFetchDialogIndex)
  ))
_sym_db.RegisterMessage(ResponseFetchDialogIndex)

RequestLoadArchived = _reflection.GeneratedProtocolMessageType('RequestLoadArchived', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADARCHIVED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadArchived)
  ))
_sym_db.RegisterMessage(RequestLoadArchived)

ResponseLoadArchived = _reflection.GeneratedProtocolMessageType('ResponseLoadArchived', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADARCHIVED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadArchived)
  ))
_sym_db.RegisterMessage(ResponseLoadArchived)

RequestLoadGroupedDialogs = _reflection.GeneratedProtocolMessageType('RequestLoadGroupedDialogs', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADGROUPEDDIALOGS,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadGroupedDialogs)
  ))
_sym_db.RegisterMessage(RequestLoadGroupedDialogs)

ResponseLoadGroupedDialogs = _reflection.GeneratedProtocolMessageType('ResponseLoadGroupedDialogs', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADGROUPEDDIALOGS,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadGroupedDialogs)
  ))
_sym_db.RegisterMessage(ResponseLoadGroupedDialogs)

ResponseDialogsOrder = _reflection.GeneratedProtocolMessageType('ResponseDialogsOrder', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEDIALOGSORDER,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseDialogsOrder)
  ))
_sym_db.RegisterMessage(ResponseDialogsOrder)

RequestHideDialog = _reflection.GeneratedProtocolMessageType('RequestHideDialog', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTHIDEDIALOG,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestHideDialog)
  ))
_sym_db.RegisterMessage(RequestHideDialog)

RequestShowDialog = _reflection.GeneratedProtocolMessageType('RequestShowDialog', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSHOWDIALOG,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestShowDialog)
  ))
_sym_db.RegisterMessage(RequestShowDialog)

RequestFavouriteDialog = _reflection.GeneratedProtocolMessageType('RequestFavouriteDialog', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTFAVOURITEDIALOG,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestFavouriteDialog)
  ))
_sym_db.RegisterMessage(RequestFavouriteDialog)

RequestUnfavouriteDialog = _reflection.GeneratedProtocolMessageType('RequestUnfavouriteDialog', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTUNFAVOURITEDIALOG,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnfavouriteDialog)
  ))
_sym_db.RegisterMessage(RequestUnfavouriteDialog)

UpdateDialogFavouriteChanged = _reflection.GeneratedProtocolMessageType('UpdateDialogFavouriteChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEDIALOGFAVOURITECHANGED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateDialogFavouriteChanged)
  ))
_sym_db.RegisterMessage(UpdateDialogFavouriteChanged)

RequestNotifyDialogOpened = _reflection.GeneratedProtocolMessageType('RequestNotifyDialogOpened', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTNOTIFYDIALOGOPENED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestNotifyDialogOpened)
  ))
_sym_db.RegisterMessage(RequestNotifyDialogOpened)

PinnedMessages = _reflection.GeneratedProtocolMessageType('PinnedMessages', (_message.Message,), dict(
  DESCRIPTOR = _PINNEDMESSAGES,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PinnedMessages)
  ))
_sym_db.RegisterMessage(PinnedMessages)

RequestPinMessage = _reflection.GeneratedProtocolMessageType('RequestPinMessage', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTPINMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestPinMessage)
  ))
_sym_db.RegisterMessage(RequestPinMessage)

RequestUnpinMessage = _reflection.GeneratedProtocolMessageType('RequestUnpinMessage', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTUNPINMESSAGE,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnpinMessage)
  ))
_sym_db.RegisterMessage(RequestUnpinMessage)

UpdatePinnedMessagesChanged = _reflection.GeneratedProtocolMessageType('UpdatePinnedMessagesChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPINNEDMESSAGESCHANGED,
  __module__ = 'messaging_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdatePinnedMessagesChanged)
  ))
_sym_db.RegisterMessage(UpdatePinnedMessagesChanged)


DESCRIPTOR._options = None
_MESSAGEATTRIBUTES.fields_by_name['is_mentioned']._options = None
_MESSAGEATTRIBUTES.fields_by_name['is_highlighted']._options = None
_MESSAGEATTRIBUTES.fields_by_name['is_notified']._options = None
_MESSAGEATTRIBUTES.fields_by_name['is_only_for_you']._options = None
_QUOTEDMESSAGE.fields_by_name['message_id']._options = None
_QUOTEDMESSAGE.fields_by_name['public_group_id']._options = None
_QUOTEDMESSAGE.fields_by_name['sender_user_id']._options = None
_QUOTEDMESSAGE.fields_by_name['message_date']._options = None
_QUOTEDMESSAGE.fields_by_name['quoted_message_content']._options = None
_MESSAGEMEDIA.fields_by_name['webpage']._options = None
_MESSAGEMEDIA.fields_by_name['image']._options = None
_MESSAGEMEDIA.fields_by_name['audio']._options = None
_MESSAGEMEDIA.fields_by_name['actions']._options = None
_WEBPAGEMEDIA.fields_by_name['url']._options = None
_WEBPAGEMEDIA.fields_by_name['title']._options = None
_WEBPAGEMEDIA.fields_by_name['description']._options = None
_WEBPAGEMEDIA.fields_by_name['image']._options = None
_IMAGEMEDIA.fields_by_name['image']._options = None
_AUDIOMEDIA.fields_by_name['audio']._options = None
_INTERACTIVEMEDIABUTTON.fields_by_name['value']._options = None
_INTERACTIVEMEDIABUTTON.fields_by_name['label']._options = None
_INTERACTIVEMEDIASELECT.fields_by_name['options']._options = None
_INTERACTIVEMEDIASELECT.fields_by_name['label']._options = None
_INTERACTIVEMEDIASELECT.fields_by_name['default_value']._options = None
_INTERACTIVEMEDIASELECTOPTION.fields_by_name['value']._options = None
_INTERACTIVEMEDIASELECTOPTION.fields_by_name['label']._options = None
_INTERACTIVEMEDIA.fields_by_name['id']._options = None
_INTERACTIVEMEDIA.fields_by_name['widget']._options = None
_INTERACTIVEMEDIA.fields_by_name['style']._options = None
_INTERACTIVEMEDIA.fields_by_name['confirm']._options = None
_INTERACTIVEMEDIATRANSLATION.fields_by_name['id']._options = None
_INTERACTIVEMEDIATRANSLATION.fields_by_name['value']._options = None
_INTERACTIVEMEDIATRANSLATIONGROUP.fields_by_name['language']._options = None
_INTERACTIVEMEDIATRANSLATIONGROUP.fields_by_name['messages']._options = None
_INTERACTIVEMEDIAGROUP.fields_by_name['actions']._options = None
_INTERACTIVEMEDIAGROUP.fields_by_name['title']._options = None
_INTERACTIVEMEDIAGROUP.fields_by_name['description']._options = None
_INTERACTIVEMEDIAGROUP.fields_by_name['translations']._options = None
_INTERACTIVEMEDIACONFIRM.fields_by_name['text']._options = None
_INTERACTIVEMEDIACONFIRM.fields_by_name['title']._options = None
_INTERACTIVEMEDIACONFIRM.fields_by_name['ok']._options = None
_INTERACTIVEMEDIACONFIRM.fields_by_name['dismiss']._options = None
_UPDATEINTERACTIVEMEDIAEVENT.fields_by_name['mid']._options = None
_UPDATEINTERACTIVEMEDIAEVENT.fields_by_name['id']._options = None
_UPDATEINTERACTIVEMEDIAEVENT.fields_by_name['value']._options = None
_UPDATEINTERACTIVEMEDIAEVENT.fields_by_name['uid']._options = None
_REQUESTDOINTERACTIVEMEDIAACTION.fields_by_name['mid']._options = None
_REQUESTDOINTERACTIVEMEDIAACTION.fields_by_name['id']._options = None
_REQUESTDOINTERACTIVEMEDIAACTION.fields_by_name['value']._options = None
_REQUESTDOINTERACTIVEMEDIAACTION._options = None
_TEXTMESSAGE.fields_by_name['text']._options = None
_TEXTMESSAGE.fields_by_name['mentions']._options = None
_TEXTMESSAGE.fields_by_name['ext']._options = None
_TEXTMESSAGE.fields_by_name['media']._options = None
_TEXTMESSAGE.fields_by_name['extensions']._options = None
_TEXTEXMARKDOWN.fields_by_name['markdown']._options = None
_TEXTMODERNMESSAGE.fields_by_name['text']._options = None
_TEXTMODERNMESSAGE.fields_by_name['sender_name_override']._options = None
_TEXTMODERNMESSAGE.fields_by_name['sender_photo_override']._options = None
_TEXTMODERNMESSAGE.fields_by_name['style']._options = None
_TEXTMODERNMESSAGE.fields_by_name['attaches']._options = None
_PARAGRAPHSTYLE.fields_by_name['show_paragraph']._options = None
_PARAGRAPHSTYLE.fields_by_name['paragraph_color']._options = None
_PARAGRAPHSTYLE.fields_by_name['bg_color']._options = None
_TEXTMODERNATTACH.fields_by_name['title']._options = None
_TEXTMODERNATTACH.fields_by_name['title_url']._options = None
_TEXTMODERNATTACH.fields_by_name['title_icon']._options = None
_TEXTMODERNATTACH.fields_by_name['text']._options = None
_TEXTMODERNATTACH.fields_by_name['style']._options = None
_TEXTMODERNFIELD.fields_by_name['title']._options = None
_TEXTMODERNFIELD.fields_by_name['value']._options = None
_TEXTMODERNFIELD.fields_by_name['is_short']._options = None
_TEXTCOMMAND.fields_by_name['command']._options = None
_TEXTCOMMAND.fields_by_name['args']._options = None
_SERVICEMESSAGE.fields_by_name['text']._options = None
_SERVICEMESSAGE.fields_by_name['ext']._options = None
_SERVICEEXUSERINVITED.fields_by_name['invited_uid']._options = None
_SERVICEEXUSERKICKED.fields_by_name['kicked_uid']._options = None
_SERVICEEXCHANGEDTITLE.fields_by_name['title']._options = None
_SERVICEEXCHANGEDTOPIC.fields_by_name['topic']._options = None
_SERVICEEXCHANGEDABOUT.fields_by_name['about']._options = None
_SERVICEEXCHANGEDAVATAR.fields_by_name['avatar']._options = None
_SERVICEEXCONTACTREGISTERED.fields_by_name['uid']._options = None
_SERVICEEXPHONECALL.fields_by_name['duration']._options = None
_DOCUMENTMESSAGE.fields_by_name['file_id']._options = None
_DOCUMENTMESSAGE.fields_by_name['access_hash']._options = None
_DOCUMENTMESSAGE.fields_by_name['file_size']._options = None
_DOCUMENTMESSAGE.fields_by_name['name']._options = None
_DOCUMENTMESSAGE.fields_by_name['mime_type']._options = None
_DOCUMENTMESSAGE.fields_by_name['thumb']._options = None
_DOCUMENTMESSAGE.fields_by_name['ext']._options = None
_DOCUMENTEXPHOTO.fields_by_name['w']._options = None
_DOCUMENTEXPHOTO.fields_by_name['h']._options = None
_DOCUMENTEXVIDEO.fields_by_name['w']._options = None
_DOCUMENTEXVIDEO.fields_by_name['h']._options = None
_DOCUMENTEXVIDEO.fields_by_name['duration']._options = None
_DOCUMENTEXVOICE.fields_by_name['duration']._options = None
_JSONMESSAGE.fields_by_name['raw_json']._options = None
_STICKERMESSAGE.fields_by_name['sticker_id']._options = None
_STICKERMESSAGE.fields_by_name['fast_preview']._options = None
_STICKERMESSAGE.fields_by_name['image_512']._options = None
_STICKERMESSAGE.fields_by_name['image_256']._options = None
_STICKERMESSAGE.fields_by_name['sticker_collection_id']._options = None
_STICKERMESSAGE.fields_by_name['sticker_collection_access_hash']._options = None
_STICKERMESSAGE.fields_by_name['emoji']._options = None
_BINARYMESSAGE.fields_by_name['content_tag']._options = None
_BINARYMESSAGE.fields_by_name['msg']._options = None
_DELETEDMESSAGE.fields_by_name['is_local']._options = None
_DIALOGSHORT.fields_by_name['peer']._options = None
_DIALOGSHORT.fields_by_name['counter']._options = None
_DIALOGSHORT.fields_by_name['date']._options = None
_DIALOGGROUP.fields_by_name['title']._options = None
_DIALOGGROUP.fields_by_name['key']._options = None
_DIALOGGROUP.fields_by_name['dialogs']._options = None
_MESSAGEREACTION.fields_by_name['users']._options = None
_MESSAGEREACTION.fields_by_name['code']._options = None
_SEARCHPREDICATE.fields_by_name['key']._options = None
_SEARCHPREDICATE.fields_by_name['values']._options = None
_REQUESTSENDMESSAGE.fields_by_name['peer']._options = None
_REQUESTSENDMESSAGE.fields_by_name['deduplication_id']._options = None
_REQUESTSENDMESSAGE.fields_by_name['message']._options = None
_REQUESTSENDMESSAGE.fields_by_name['is_only_for_user']._options = None
_REQUESTSENDMESSAGE.fields_by_name['forward']._options = None
_REQUESTSENDMESSAGE.fields_by_name['reply']._options = None
_REQUESTSENDMESSAGE.fields_by_name['predicates']._options = None
_REQUESTSENDMESSAGE.fields_by_name['white_list']._options = None
_REQUESTSENDMESSAGE.fields_by_name['black_list']._options = None
_REQUESTSENDMESSAGE._options = None
_REQUESTUPDATEMESSAGE.fields_by_name['mid']._options = None
_REQUESTUPDATEMESSAGE.fields_by_name['updated_message']._options = None
_REQUESTUPDATEMESSAGE.fields_by_name['last_edited_at']._options = None
_REQUESTUPDATEMESSAGE._options = None
_REQUESTMESSAGERECEIVED.fields_by_name['peer']._options = None
_REQUESTMESSAGERECEIVED.fields_by_name['date']._options = None
_REQUESTMESSAGERECEIVED._options = None
_REQUESTMESSAGEREAD.fields_by_name['peer']._options = None
_REQUESTMESSAGEREAD.fields_by_name['date']._options = None
_REQUESTMESSAGEREAD._options = None
_REQUESTDELETEMESSAGEOBSOLETE.fields_by_name['mids']._options = None
_REQUESTDELETEMESSAGEOBSOLETE._options = None
_REQUESTCLEARCHAT.fields_by_name['peer']._options = None
_REQUESTCLEARCHAT.fields_by_name['last_message_date']._options = None
_REQUESTCLEARCHAT._options = None
_REQUESTDELETECHAT.fields_by_name['peer']._options = None
_REQUESTDELETECHAT.fields_by_name['last_message_date']._options = None
_REQUESTDELETECHAT._options = None
_REQUESTARCHIVECHAT.fields_by_name['peer']._options = None
_REQUESTARCHIVECHAT._options = None
_REQUESTMESSAGESETREACTION.fields_by_name['peer']._options = None
_REQUESTMESSAGESETREACTION.fields_by_name['mid']._options = None
_REQUESTMESSAGESETREACTION.fields_by_name['code']._options = None
_REQUESTMESSAGESETREACTION._options = None
_REQUESTMESSAGEREMOVEREACTION.fields_by_name['peer']._options = None
_REQUESTMESSAGEREMOVEREACTION.fields_by_name['mid']._options = None
_REQUESTMESSAGEREMOVEREACTION.fields_by_name['code']._options = None
_REQUESTMESSAGEREMOVEREACTION._options = None
_RESPONSEREACTIONSRESPONSE._options = None
_RESPONSESENDMESSAGE.fields_by_name['mid']._options = None
_RESPONSESENDMESSAGE._options = None
_UPDATEMESSAGE.fields_by_name['peer']._options = None
_UPDATEMESSAGE.fields_by_name['sender_uid']._options = None
_UPDATEMESSAGE.fields_by_name['date']._options = None
_UPDATEMESSAGE.fields_by_name['mid']._options = None
_UPDATEMESSAGE.fields_by_name['message']._options = None
_UPDATEMESSAGE.fields_by_name['attributes']._options = None
_UPDATEMESSAGE.fields_by_name['forward']._options = None
_UPDATEMESSAGE.fields_by_name['reply']._options = None
_UPDATEMESSAGE.fields_by_name['previous_mid']._options = None
_UPDATEMESSAGE.fields_by_name['counter']._options = None
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['peer']._options = None
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['mid']._options = None
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['message']._options = None
_UPDATEMESSAGECONTENTCHANGED.fields_by_name['edited_at']._options = None
_UPDATEMESSAGESENT.fields_by_name['peer']._options = None
_UPDATEMESSAGESENT.fields_by_name['rid']._options = None
_UPDATEMESSAGESENT.fields_by_name['date']._options = None
_UPDATEMESSAGESENT.fields_by_name['mid']._options = None
_UPDATEMESSAGESENT.fields_by_name['prev_mid']._options = None
_UPDATEMESSAGESENT.fields_by_name['unread_counter']._options = None
_UPDATEMESSAGERECEIVED.fields_by_name['peer']._options = None
_UPDATEMESSAGERECEIVED.fields_by_name['start_date']._options = None
_UPDATEMESSAGERECEIVED.fields_by_name['received_date']._options = None
_UPDATEMESSAGEREAD.fields_by_name['peer']._options = None
_UPDATEMESSAGEREAD.fields_by_name['start_date']._options = None
_UPDATEMESSAGEREAD.fields_by_name['read_date']._options = None
_UPDATEMESSAGEREADBYME.fields_by_name['peer']._options = None
_UPDATEMESSAGEREADBYME.fields_by_name['start_date']._options = None
_UPDATEMESSAGEREADBYME.fields_by_name['unread_counter']._options = None
_UPDATEMESSAGEDELETE.fields_by_name['peer']._options = None
_UPDATEMESSAGEDELETE.fields_by_name['mids']._options = None
_UPDATEMESSAGEDELETE.fields_by_name['counter']._options = None
_UPDATEMESSAGEDELETE.fields_by_name['action_date']._options = None
_UPDATECHATCLEAR.fields_by_name['peer']._options = None
_UPDATECHATCLEAR.fields_by_name['action_date']._options = None
_UPDATECHATDELETE.fields_by_name['peer']._options = None
_UPDATECHATDELETE.fields_by_name['action_date']._options = None
_UPDATECHATARCHIVE.fields_by_name['peer']._options = None
_UPDATECHATGROUPSCHANGED.fields_by_name['dialogs']._options = None
_UPDATEREACTIONSUPDATE.fields_by_name['peer']._options = None
_UPDATEREACTIONSUPDATE.fields_by_name['mid']._options = None
_UPDATEREACTIONSUPDATE.fields_by_name['reactions']._options = None
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['peer']._options = None
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['rid']._options = None
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['date']._options = None
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['hookId']._options = None
_UPDATEMESSAGEREJECTEDBYHOOK.fields_by_name['reason']._options = None
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['peer']._options = None
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['mid']._options = None
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['date']._options = None
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['hookId']._options = None
_UPDATEMESSAGEEDITREJECTEDBYHOOK.fields_by_name['reason']._options = None
_REFERENCEDMESSAGES.fields_by_name['mids']._options = None
_HISTORYMESSAGE.fields_by_name['sender_uid']._options = None
_HISTORYMESSAGE.fields_by_name['host_peer']._options = None
_HISTORYMESSAGE.fields_by_name['mid']._options = None
_HISTORYMESSAGE.fields_by_name['date']._options = None
_HISTORYMESSAGE.fields_by_name['message']._options = None
_HISTORYMESSAGE.fields_by_name['state']._options = None
_HISTORYMESSAGE.fields_by_name['reactions']._options = None
_HISTORYMESSAGE.fields_by_name['attribute']._options = None
_HISTORYMESSAGE.fields_by_name['edited_at']._options = None
_REQUESTLOADHISTORY.fields_by_name['peer']._options = None
_REQUESTLOADHISTORY.fields_by_name['date']._options = None
_REQUESTLOADHISTORY.fields_by_name['load_mode']._options = None
_REQUESTLOADHISTORY.fields_by_name['limit']._options = None
_REQUESTLOADHISTORY.fields_by_name['optimizations']._options = None
_REQUESTLOADHISTORY._options = None
_RESPONSELOADHISTORY._options = None
_DIALOG.fields_by_name['peer']._options = None
_DIALOG.fields_by_name['unread_count']._options = None
_DIALOG.fields_by_name['sort_date']._options = None
_DIALOG.fields_by_name['sender_uid']._options = None
_DIALOG.fields_by_name['is_favourite']._options = None
_DIALOG.fields_by_name['mid']._options = None
_DIALOG.fields_by_name['date']._options = None
_DIALOG.fields_by_name['message']._options = None
_DIALOG.fields_by_name['first_unread_date']._options = None
_DIALOG.fields_by_name['attributes']._options = None
_DIALOG.fields_by_name['pinned_messages']._options = None
_DIALOG.fields_by_name['history_message']._options = None
_REQUESTLOADDIALOGS.fields_by_name['min_date']._options = None
_REQUESTLOADDIALOGS.fields_by_name['limit']._options = None
_REQUESTLOADDIALOGS.fields_by_name['optimizations']._options = None
_REQUESTLOADDIALOGS.fields_by_name['filters']._options = None
_REQUESTLOADDIALOGS.fields_by_name['peers_to_load']._options = None
_REQUESTLOADDIALOGS._options = None
_RESPONSELOADDIALOGS._options = None
_DIALOGINDEX.fields_by_name['peer']._options = None
_DIALOGINDEX.fields_by_name['timestamp']._options = None
_REQUESTFETCHDIALOGINDEX._options = None
_RESPONSEFETCHDIALOGINDEX._options = None
_REQUESTLOADARCHIVED.fields_by_name['next_offset']._options = None
_REQUESTLOADARCHIVED.fields_by_name['limit']._options = None
_REQUESTLOADARCHIVED.fields_by_name['optimizations']._options = None
_REQUESTLOADARCHIVED._options = None
_RESPONSELOADARCHIVED._options = None
_REQUESTLOADGROUPEDDIALOGS._options = None
_RESPONSELOADGROUPEDDIALOGS._options = None
_RESPONSEDIALOGSORDER.fields_by_name['seq']._options = None
_RESPONSEDIALOGSORDER.fields_by_name['state']._options = None
_RESPONSEDIALOGSORDER.fields_by_name['groups']._options = None
_RESPONSEDIALOGSORDER._options = None
_REQUESTHIDEDIALOG.fields_by_name['peer']._options = None
_REQUESTHIDEDIALOG._options = None
_REQUESTSHOWDIALOG._options = None
_REQUESTFAVOURITEDIALOG.fields_by_name['peer']._options = None
_REQUESTFAVOURITEDIALOG._options = None
_REQUESTUNFAVOURITEDIALOG.fields_by_name['peer']._options = None
_REQUESTUNFAVOURITEDIALOG._options = None
_UPDATEDIALOGFAVOURITECHANGED.fields_by_name['peer']._options = None
_UPDATEDIALOGFAVOURITECHANGED.fields_by_name['is_favourite']._options = None
_REQUESTNOTIFYDIALOGOPENED.fields_by_name['peer']._options = None
_REQUESTNOTIFYDIALOGOPENED._options = None
_PINNEDMESSAGES.fields_by_name['mids']._options = None
_REQUESTPINMESSAGE.fields_by_name['peer']._options = None
_REQUESTPINMESSAGE.fields_by_name['mid']._options = None
_REQUESTPINMESSAGE.fields_by_name['last_pin_date']._options = None
_REQUESTPINMESSAGE._options = None
_REQUESTUNPINMESSAGE.fields_by_name['peer']._options = None
_REQUESTUNPINMESSAGE.fields_by_name['mid']._options = None
_REQUESTUNPINMESSAGE.fields_by_name['last_pin_date']._options = None
_REQUESTUNPINMESSAGE._options = None
_UPDATEPINNEDMESSAGESCHANGED.fields_by_name['peer']._options = None
_UPDATEPINNEDMESSAGESCHANGED.fields_by_name['pinned_messages']._options = None
_UPDATEPINNEDMESSAGESCHANGED.fields_by_name['action_date']._options = None

_MESSAGING = _descriptor.ServiceDescriptor(
  name='Messaging',
  full_name='dialog.Messaging',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=19035,
  serialized_end=21868,
  methods=[
  _descriptor.MethodDescriptor(
    name='DoInteractiveMediaAction',
    full_name='dialog.Messaging.DoInteractiveMediaAction',
    index=0,
    containing_service=None,
    input_type=_REQUESTDOINTERACTIVEMEDIAACTION,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0020\"+/v1/grpc/Messaging/DoInteractiveMediaAction:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SendMessage',
    full_name='dialog.Messaging.SendMessage',
    index=1,
    containing_service=None,
    input_type=_REQUESTSENDMESSAGE,
    output_type=_RESPONSESENDMESSAGE,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Messaging/SendMessage:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMessage',
    full_name='dialog.Messaging.UpdateMessage',
    index=2,
    containing_service=None,
    input_type=_REQUESTUPDATEMESSAGE,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002%\" /v1/grpc/Messaging/UpdateMessage:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageReceived',
    full_name='dialog.Messaging.MessageReceived',
    index=3,
    containing_service=None,
    input_type=_REQUESTMESSAGERECEIVED,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\'\"\"/v1/grpc/Messaging/MessageReceived:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageRead',
    full_name='dialog.Messaging.MessageRead',
    index=4,
    containing_service=None,
    input_type=_REQUESTMESSAGEREAD,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Messaging/MessageRead:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMessageObsolete',
    full_name='dialog.Messaging.DeleteMessageObsolete',
    index=5,
    containing_service=None,
    input_type=_REQUESTDELETEMESSAGEOBSOLETE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/Messaging/DeleteMessageObsolete:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ClearChat',
    full_name='dialog.Messaging.ClearChat',
    index=6,
    containing_service=None,
    input_type=_REQUESTCLEARCHAT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002!\"\034/v1/grpc/Messaging/ClearChat:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteChat',
    full_name='dialog.Messaging.DeleteChat',
    index=7,
    containing_service=None,
    input_type=_REQUESTDELETECHAT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Messaging/DeleteChat:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ArchiveChat',
    full_name='dialog.Messaging.ArchiveChat',
    index=8,
    containing_service=None,
    input_type=_REQUESTARCHIVECHAT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Messaging/ArchiveChat:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageSetReaction',
    full_name='dialog.Messaging.MessageSetReaction',
    index=9,
    containing_service=None,
    input_type=_REQUESTMESSAGESETREACTION,
    output_type=_RESPONSEREACTIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/Messaging/MessageSetReaction:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageRemoveReaction',
    full_name='dialog.Messaging.MessageRemoveReaction',
    index=10,
    containing_service=None,
    input_type=_REQUESTMESSAGEREMOVEREACTION,
    output_type=_RESPONSEREACTIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/Messaging/MessageRemoveReaction:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadHistory',
    full_name='dialog.Messaging.LoadHistory',
    index=11,
    containing_service=None,
    input_type=_REQUESTLOADHISTORY,
    output_type=_RESPONSELOADHISTORY,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Messaging/LoadHistory:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadDialogs',
    full_name='dialog.Messaging.LoadDialogs',
    index=12,
    containing_service=None,
    input_type=_REQUESTLOADDIALOGS,
    output_type=_RESPONSELOADDIALOGS,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Messaging/LoadDialogs:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='FetchDialogIndex',
    full_name='dialog.Messaging.FetchDialogIndex',
    index=13,
    containing_service=None,
    input_type=_REQUESTFETCHDIALOGINDEX,
    output_type=_RESPONSEFETCHDIALOGINDEX,
    serialized_options=_b('\202\323\344\223\002(\"#/v1/grpc/Messaging/FetchDialogIndex:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadArchived',
    full_name='dialog.Messaging.LoadArchived',
    index=14,
    containing_service=None,
    input_type=_REQUESTLOADARCHIVED,
    output_type=_RESPONSELOADARCHIVED,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Messaging/LoadArchived:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadGroupedDialogs',
    full_name='dialog.Messaging.LoadGroupedDialogs',
    index=15,
    containing_service=None,
    input_type=_REQUESTLOADGROUPEDDIALOGS,
    output_type=_RESPONSELOADGROUPEDDIALOGS,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/Messaging/LoadGroupedDialogs:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='HideDialog',
    full_name='dialog.Messaging.HideDialog',
    index=16,
    containing_service=None,
    input_type=_REQUESTHIDEDIALOG,
    output_type=_RESPONSEDIALOGSORDER,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Messaging/HideDialog:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ShowDialog',
    full_name='dialog.Messaging.ShowDialog',
    index=17,
    containing_service=None,
    input_type=_REQUESTSHOWDIALOG,
    output_type=_RESPONSEDIALOGSORDER,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Messaging/ShowDialog:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='FavouriteDialog',
    full_name='dialog.Messaging.FavouriteDialog',
    index=18,
    containing_service=None,
    input_type=_REQUESTFAVOURITEDIALOG,
    output_type=_RESPONSEDIALOGSORDER,
    serialized_options=_b('\202\323\344\223\002\'\"\"/v1/grpc/Messaging/FavouriteDialog:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UnfavouriteDialog',
    full_name='dialog.Messaging.UnfavouriteDialog',
    index=19,
    containing_service=None,
    input_type=_REQUESTUNFAVOURITEDIALOG,
    output_type=_RESPONSEDIALOGSORDER,
    serialized_options=_b('\202\323\344\223\002)\"$/v1/grpc/Messaging/UnfavouriteDialog:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyDialogOpened',
    full_name='dialog.Messaging.NotifyDialogOpened',
    index=20,
    containing_service=None,
    input_type=_REQUESTNOTIFYDIALOGOPENED,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/Messaging/NotifyDialogOpened:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PinMessage',
    full_name='dialog.Messaging.PinMessage',
    index=21,
    containing_service=None,
    input_type=_REQUESTPINMESSAGE,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Messaging/PinMessage:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UnpinMessage',
    full_name='dialog.Messaging.UnpinMessage',
    index=22,
    containing_service=None,
    input_type=_REQUESTUNPINMESSAGE,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Messaging/UnpinMessage:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_MESSAGING)

DESCRIPTOR.services_by_name['Messaging'] = _MESSAGING

# @@protoc_insertion_point(module_scope)
